@@ -16,5 +16,5 @@ void main()
         output();
     }
 
-  nport(plotlogreg("cda88", "nremiss/ncases", "labind", 5, 0.95), 1, 1);
+  nport(plotlogreg("cda88", "nremiss/ncases", "labind", 5, "", 1, 0.95), 4, 4);
 }
