@@ -51,12 +51,14 @@ static DFILE *dfile;
 DFILE *dap_in[2];	/* input files */
 DFILE *dap_out;		/* output file */
 FILE *dap_lst;		/* .lst file */
-FILE *dap_log;		/* .log file, for errors */
+FILE *dap_log;		/* .log file, for lines read, written */
+FILE *dap_err;		/* .err file, for errors */
 int dap_ono;		/* specifies which set of variable values (dataobs) to use */
 int dap_delim;		/* delimiter for reading data files (not datasets) */
 static int *fieldwd;	/* width of fixed width input data fields */
 static int nfields;		/* number of fixed width input data fields */
 static int lineno[2];		/* line number for up to 2 input datasets */
+static int outline;		/* number of lines written */
 static int pageno;		/* output page number */
 static int eof[2];		/* flags: has EOF been reached on input file(s)? */
 static long filepos[2];		/* file positions of input file(s) */
@@ -116,7 +118,7 @@ if (dap_memtrace)
 free(ptr);
 }
 
-void dap_param();
+/* void dap_param(); */
 
 static void initdo(dataobs *dato)
 {
@@ -143,11 +145,12 @@ int main(int argc, char **argv)
 {
 char *lstname;		/* name of .lst file */
 char *logname;		/* name of .log file */
-int len;		/* length of lstname, logname */
+char *errname;		/* name of .err file */
+int len;		/* length of lstname, logname, errname */
 int v;			/* index to variables */
 double testd;           /* to check endianness */
 
-dap_param();
+/* dap_param(); */
 dap_dapname = argv[0];
 len = strlen(argv[0]);
 lstname = malloc(len + 5);	/* room for suffix */
@@ -172,6 +175,14 @@ if (!(dap_log = fopen(logname, "w")))
 	perror(dap_dapname);
 	exit(1);
 	}
+errname = malloc(len + 1);
+strcpy(errname, lstname);
+strcpy(errname + len - 3, "err");
+if (!(dap_err = fopen(errname, "w")))
+	{
+	perror(dap_dapname);
+	exit(1);
+	}
 initdo(dap_obs);
 initdo(dap_obs + 1);
 initdo(dap_obs + 2);
@@ -253,7 +264,7 @@ if (!rfileinit)
 	}
 if (!fname)
 	{
-	fputs("(dfopen) no file name given\n", dap_log);
+	fputs("(dfopen) no file name given\n", dap_err);
 	exit(1);
 	}
 if (fname[0] == '<')
@@ -312,7 +323,7 @@ if (fname[0] == '<')
 		}
 	else
 		{
-		fprintf(dap_log, "(dfopen) bad mode: %s\n", mode);
+		fprintf(dap_err, "(dfopen) bad mode: %s\n", mode);
 		exit(1);
 		}
 	}
@@ -376,7 +387,7 @@ else if (fp->dfile_ram->rfile_pos > fp->dfile_ram->rfile_str)
 	}
 else
 	{
-	fprintf(dap_log, "(undgetc) can't unget past beginning of file %s\n",
+	fprintf(dap_err, "(undgetc) can't unget past beginning of file %s\n",
 			fp->dfile_name);
 	exit(1);
 	}
@@ -393,7 +404,7 @@ else if (fp->dfile_ram->rfile_pos < fp->dfile_ram->rfile_str + dap_rfilesize)
 	}
 else
 	{
-	fprintf(dap_log, "(dap_putc) too many characters: %s\n",
+	fprintf(dap_err, "(dap_putc) too many characters: %s\n",
 			fp->dfile_name);
 	exit(1);
 	}
@@ -455,7 +466,7 @@ if (suff[0] == '<')
 		}
 	if (n < 0)
 		{
-		fprintf(dap_log, "(dap_suffix) Source name has no '.': %s\n", src);
+		fprintf(dap_err, "(dap_suffix) source name has no '.': %s\n", src);
 		exit(1);
 		}
 	n++;
@@ -536,7 +547,7 @@ case DSET:
 		else
 			{
 			line[l] = '\0';
-			fprintf(dap_log, "(getline) Line too long:\n%s\n", line);
+			fprintf(dap_err, "(getline) line too long:\n%s\n", line);
 			exit(1);
 			}
 		}
@@ -556,7 +567,7 @@ case DBASE:
 	line[l] = '\0';
 	break;
 default:
-	fprintf(dap_log, "(getline) Bad infile type: %d\n", intype);
+	fprintf(dap_err, "(getline) bad infile type: %d\n", intype);
 	exit(1);
 	}
 if (!l && c == EOF)
@@ -649,21 +660,21 @@ for (iv = 0; iv < dap_obs[dap_ono].do_ivar; iv++)
 		{
 	case DBL:
 		dap_obs[dap_ono].do_dbl[dap_obs[dap_ono].do_in[iv]] =
-			dosave.do_dbl[dosave.do_in[iv]];
+			dosave.do_dbl[dap_obs[dap_ono].do_in[iv]];
 		if (dap_obs[dap_ono].do_dl[dap_obs[dap_ono].do_in[iv]])
 			*dap_obs[dap_ono].do_dl[dap_obs[dap_ono].do_in[iv]] =
 			dap_obs[dap_ono].do_dbl[dap_obs[dap_ono].do_in[iv]];
 		break;
 	case INT:
 		dap_obs[dap_ono].do_int[dap_obs[dap_ono].do_in[iv]] =
-			dosave.do_int[dosave.do_in[iv]];
+			dosave.do_int[dap_obs[dap_ono].do_in[iv]];
 		if (dap_obs[dap_ono].do_il[dap_obs[dap_ono].do_in[iv]])
 			*dap_obs[dap_ono].do_il[dap_obs[dap_ono].do_in[iv]] =
 			dap_obs[dap_ono].do_int[dap_obs[dap_ono].do_in[iv]];
 		break;
 	default:
 		strncpy(dap_obs[dap_ono].do_str[dap_obs[dap_ono].do_in[iv]],
-			dosave.do_str[dosave.do_in[iv]],
+			dosave.do_str[dap_obs[dap_ono].do_in[iv]],
 			dap_obs[dap_ono].do_len[dap_obs[dap_ono].do_in[iv]] + 1);
 		break;
 		}
@@ -692,7 +703,7 @@ else
 		fp->dfile_ram->rfile_pos = fp->dfile_ram->rfile_str + pos;
 	else
 		{
-		fprintf(dap_log, "(dfseek) Seek past end of ramfile %s\n",
+		fprintf(dap_err, "(dfseek) seek past end of ramfile %s\n",
 			fp->dfile_name);
 		exit(1);
 		}
@@ -710,7 +721,7 @@ if (dap_in[dap_ono])
 	}
 else
 	{
-	fprintf(dap_log, "(dap_rewind) File (%d) is closed.\n", dap_ono);
+	fprintf(dap_err, "(dap_rewind) file (%d) is closed.\n", dap_ono);
 	exit(1);
 	}
 }
@@ -735,7 +746,7 @@ while (--nlines >= 0)
 	{
 	if (!dap_in[dap_ono] || eof[dap_ono])
 		{
-		fprintf(dap_log, "(skip) Tried to read past end of file (%d).\n",
+		fprintf(dap_err, "(skip) tried to read past end of file (%d).\n",
 						dap_ono);
 		exit(1);
 		}
@@ -764,7 +775,8 @@ if (!stepinit)
 	}
 if (!dap_in[dap_ono] || eof[dap_ono])
 	{
-	fprintf(dap_log, "(step) Tried to read past end of file (%d).\n", dap_ono);
+	fprintf(dap_err, "(step) ERROR: tried to read past end of file (%s).\n",
+		(dap_in[dap_ono] ? dap_in[dap_ono]->dfile_name : "?"));
 	exit(1);
 	}
 for (iv = 0; iv < dap_obs[dap_ono].do_ivar; iv++)
@@ -790,12 +802,17 @@ if (getline(dap_in[dap_ono], line) < 0)
 	{
 	eof[dap_ono] = 1;
 	dap_obs[dap_ono].do_valid = 0;
+	fprintf(stderr, "(step) %d lines read from  %s\n",
+		lineno[dap_ono] - 1, dap_in[dap_ono]->dfile_name);
+	fflush(stderr);
+	fprintf(dap_log, "(step) %d lines read from  %s\n",
+		lineno[dap_ono] - 1, dap_in[dap_ono]->dfile_name);
 	return 0;
 	}
 if (nfields && dap_obs[dap_ono].do_ivar != nfields)
 	{
-	fprintf(dap_log,
-"(step) Number of input variables %d different from number of fields specified %d for %s.\n",
+	fprintf(dap_err,
+"(step) ERROR: number of input variables %d different from number of fields specified %d for %s.\n",
 		dap_obs[dap_ono].do_ivar, nfields, dap_in[dap_ono]->dfile_name);
 	exit(1);
 	}
@@ -809,12 +826,14 @@ for (v = 0, l = 0; v < dap_obs[dap_ono].do_ivar; v++)
 		if (i < fieldwd[v])
 			{
 			fprintf(dap_log,
-				"(step (%d)) Incomplete fixed length field for %s: %s\n",
+				"(step (%s:%d)) ERROR: incomplete fixed length field for %s: %s\n",
+				dap_in[dap_ono]->dfile_name,
 				lineno[dap_ono],
 				dap_obs[dap_ono].do_nam[dap_obs[dap_ono].do_in[v]],
 				value);
-			fprintf(dap_log,
-				"(step (%d)) Got %d of %d characters.\n",
+			fprintf(dap_err,
+				"(step (%s:%d)) ERROR: got %d of %d characters.\n",
+					dap_in[dap_ono]->dfile_name,
 					lineno[dap_ono], i, fieldwd[v]);
 			exit(1);
 			}
@@ -836,8 +855,9 @@ for (v = 0, l = 0; v < dap_obs[dap_ono].do_ivar; v++)
 				dap_obs[dap_ono].do_int[dap_obs[dap_ono].do_in[v]] = 0;
 			else
 				{
-				fprintf(dap_log,
-					"(step (%d)) Invalid integer data for %s: %s\n",
+				fprintf(dap_err,
+					"(step (%s:%d)) ERROR: invalid integer data for %s: %s\n",
+					dap_in[dap_ono]->dfile_name,
 					lineno[dap_ono],
 					dap_obs[dap_ono].do_nam[dap_obs[dap_ono].do_in[v]],
 					value);
@@ -859,8 +879,9 @@ for (v = 0, l = 0; v < dap_obs[dap_ono].do_ivar; v++)
 			else if (sscanf(value, " %lf",
 				dap_obs[dap_ono].do_dbl + dap_obs[dap_ono].do_in[v]) != 1)
 				{
-				fprintf(dap_log,
-					"(step (%d)) Invalid double data for %s: %s\n",
+				fprintf(dap_err,
+					"(step (%s:%d)) ERROR: invalid double data for %s: %s\n",
+					dap_in[dap_ono]->dfile_name,
 					lineno[dap_ono],
 					dap_obs[dap_ono].do_nam[dap_obs[dap_ono].do_in[v]],
 					value);
@@ -884,7 +905,8 @@ for (v = 0, l = 0; v < dap_obs[dap_ono].do_ivar; v++)
 			if (!toolong)
 				{
 				fprintf(dap_log,
-				"(step (%d)) String data too long (%d) for %s (%d): %s\n",
+				"(step (%s:%d)) WARNING: string data too long (%d) for %s (%d): %s\n",
+				dap_in[dap_ono]->dfile_name,
 				lineno[dap_ono], i,
 				dap_obs[dap_ono].do_nam[dap_obs[dap_ono].do_in[v]],
 				dap_obs[dap_ono].do_len[dap_obs[dap_ono].do_in[v]],
@@ -940,7 +962,7 @@ while (varspec[s])
 			i++;
 		if (!varspec[s + i])
 			{
-			fprintf(dap_log, "(dap_vd) Missing variable length: %s\n",
+			fprintf(dap_err, "(dap_vd) missing variable length: %s\n",
 									varspec + s);
 			exit(1);
 			}
@@ -961,12 +983,12 @@ while (varspec[s])
 			if (dap_obs[dap_ono].do_len[v] != vlen)
 				{
 				if (dap_obs[dap_ono].do_len[v] > 0)
-					fprintf(dap_log,
-				"(dap_vd) Respecification of length of %s from %d to %d\n",
+					fprintf(dap_err,
+				"(dap_vd) respecification of length of %s from %d to %d\n",
 						varnam, dap_obs[dap_ono].do_len[v] + 1, vlen + 1);
 				else
-					fprintf(dap_log,
-				"(dap_vd) Respecification of length of %s from %d to %d\n",
+					fprintf(dap_err,
+				"(dap_vd) respecification of length of %s from %d to %d\n",
 						varnam, dap_obs[dap_ono].do_len[v], vlen);
 				exit(1);
 				}
@@ -975,8 +997,8 @@ while (varspec[s])
 			dap_obs[dap_ono].do_len[v] = vlen;
 		if (varspec[s + i] && varspec[s + i] != ' ')
 			{
-			fprintf(dap_log,
-			"(dap_vd) Invalid variable length for %s: %s\n",
+			fprintf(dap_err,
+			"(dap_vd) invalid variable length for %s: %s\n",
 				varnam, varspec + s);
 			exit(1);
 			}
@@ -997,7 +1019,7 @@ while (varspec[s])
 		}
 	else
 		{
-		fprintf(dap_log, "(dap_vd) Too many variables: %s\n", varspec + s);
+		fprintf(dap_err, "(dap_vd) too many variables: %s\n", varspec + s);
 		exit(1);
 		}
 	if (!redeclare)
@@ -1024,7 +1046,7 @@ else
 		}
 	else
 		{
-		fprintf(dap_log, "(dap_dl) Unknown variable %s\n", varname);
+		fprintf(dap_err, "(dap_dl) unknown variable %s\n", varname);
 		exit(1);
 		}
 	}
@@ -1047,7 +1069,7 @@ else
 		}
 	else
 		{
-		fprintf(dap_log, "(dap_il) Unknown variable %s\n", varname);
+		fprintf(dap_err, "(dap_il) unknown variable %s\n", varname);
 		exit(1);
 		}
 	}
@@ -1065,7 +1087,7 @@ if ((v = dap_varnum(varname)) >= 0)
 	}
 else
 	{
-	fprintf(dap_log, "(dap_sl) Unknown variable %s\n", varname);
+	fprintf(dap_err, "(dap_sl) unknown variable %s\n", varname);
 	exit(1);
 	}
 }
@@ -1090,7 +1112,7 @@ if (stat(dname, &statbuf) < 0)
 	}
 else if (!(statbuf.st_mode & S_IFDIR))
 	{
-	fprintf(dap_log, "%s: non-directory file exists: %s\n", dap_dapname, dname);
+	fprintf(dap_err, "%s: non-directory file exists: %s\n", dap_dapname, dname);
 	exit(1);
 	}
 strcat(dname, "/");
@@ -1119,6 +1141,8 @@ int vn, nv;
 int dim, ndim;
 char *outlist;
 static char dimstr[7];	/* depends on dap_maxvar <= 10,000 */
+int *clearvar;		/* indices of variables to clear in APPEND */
+int nclear;		/* number of variables to clear */
 
 if (!datsetinit)
 	{
@@ -1148,6 +1172,7 @@ dold = dap_malloc(strlen(oldname) + strlen(dap_setdir) + 2, oldname);
 dnew = dap_malloc(strlen(newname) + strlen(dap_setdir) + 2, newname);
 dap_name(dold, oldname);
 dap_name(dnew, newname);
+clearvar = NULL;
 if (!strcmp(action, "RENAME"))
 	{
 	if (oldname[0] == '<')
@@ -1172,22 +1197,22 @@ if (!strcmp(action, "RENAME"))
 				}
 			else
 				{
-				fprintf(dap_log,
-					"(dataset) Can't find ramfile %s\n", oldname);
+				fprintf(dap_err,
+					"(dataset) can't find ramfile %s\n", oldname);
 				exit(1);
 				}
 			}
 		else
 			{
-			fprintf(dap_log,
-				"(dataset) Can't rename ramfile %s to disk file %s\n",
+			fprintf(dap_err,
+				"(dataset) can't rename ramfile %s to disk file %s\n",
 						oldname, newname);
 			exit(1);
 			}
 		}
 	else if (newname[0] == '<')
 		{
-		fprintf(dap_log, "(dataset) Can't rename disk file %s to ramfile %s\n",
+		fprintf(dap_err, "(dataset) can't rename disk file %s to ramfile %s\n",
 						oldname, newname);
 			exit(1);
 		}
@@ -1206,7 +1231,7 @@ else if (!strncmp(action, "COPY", 4))
 				oldvar[nvar][c++] = action[v++];
 			else
 				{
-				fprintf(dap_log, "(dataset) Variable name too long: %s\n",
+				fprintf(dap_err, "(dataset) variable name too long: %s\n",
 									action);
 				exit(1);
 				}
@@ -1224,8 +1249,8 @@ else if (!strncmp(action, "COPY", 4))
 					newvar[nvar][c++] = action[v++];
 				else
 					{
-					fprintf(dap_log,
-					"(dataset) New variable name too long: %s\n",
+					fprintf(dap_err,
+					"(dataset) new variable name too long: %s\n",
 									action);
 					exit(1);
 					}
@@ -1271,7 +1296,7 @@ else if (!strncmp(action, "COPY", 4))
 				}
 			else
 				{
-				fprintf(dap_log, "(dataset) Unknown variable %s\n",
+				fprintf(dap_err, "(dataset) unknown variable %s\n",
 							oldvar[v]);
 				exit(1);
 				}
@@ -1284,13 +1309,13 @@ else if (!strncmp(action, "COPY", 4))
 		{
 		if (!(doldf = dfopen(oldname, "r")))
 			{
-			fprintf(dap_log, "(dataset) Can't read %s for copy.\n",
+			fprintf(dap_err, "(dataset) can't read %s for copy.\n",
 								oldname);
 			exit(1);
 			}
 		if (!(dnewf = dfopen(newname, "w")))
 			{
-			fprintf(dap_log, "(dataset) Can't write %s for copy.\n",
+			fprintf(dap_err, "(dataset) can't write %s for copy.\n",
 								newname);
 			exit(1);
 			}
@@ -1324,14 +1349,14 @@ else if (!strcmp(action, "APPEND"))
 		{
 		if (!(dap_out = dfopen(newname, "w")))
 			{
-			fprintf(dap_log,
+			fprintf(dap_err,
 				"(dataset) Can't create new data set for append: %s\n",
 				newname);
 			exit(1);
 			}
 		if (!(dap_in[0] = dfopen(oldname, "r")))
 			{
-			fprintf(dap_log,
+			fprintf(dap_err,
 				"(dataset) Can't read old data set for append: %s\n",
 				oldname);
 			exit(1);
@@ -1346,11 +1371,11 @@ else if (!strcmp(action, "APPEND"))
 		}
 	else
 		{
-		inset(newname);
-		outset("dap_null", "");
-		baseobs.do_nvar = dap_obs[0].do_nvar;
+		inset(newname);			/* to get variable list */
+		outset("dap_null", "");		/* so don't output anywhere */
+		baseobs.do_nvar = dap_obs[0].do_nvar;	/* save newname's nvar */
 		for (v = 0; v < baseobs.do_nvar; v++)
-			{
+			{			/* copy names, lens from newname */
 			baseobs.do_len[v] = dap_obs[0].do_len[v];
 			baseobs.do_nam[v] = dap_malloc(strlen(dap_obs[0].do_nam[v]) + 1,
                                                      dap_obs[0].do_nam[v]);
@@ -1358,44 +1383,61 @@ else if (!strcmp(action, "APPEND"))
 			}
 		dfclose(dap_out);
 		dap_out = (DFILE *) NULL;
-		inset(oldname);
+		inset(oldname);		/* open dataset to append to newname */
 		dap_obs[0].do_ovar = 0;
 		for (v = 0, maxnamlen = 0; v < baseobs.do_nvar; v++)
-			{
+			{		/* find longest name length in newname */
 			if (maxnamlen < strlen(baseobs.do_nam[v]))
 				maxnamlen = strlen(baseobs.do_nam[v]);
 			}
+		/* set up for specification for declaration of those variables in
+                 * newname that are not in oldname
+                 */
 		varspec = dap_malloc(maxnamlen + dap_intlen + 2, "");
-		for (v = 0; v < baseobs.do_nvar; v++)
+		clearvar = (int *) dap_malloc(sizeof(int) * baseobs.do_nvar, "");
+		for (v = 0, nclear = 0; v < baseobs.do_nvar; v++)
 			{
 			if ((onum = dap_varnum(baseobs.do_nam[v])) < 0)
-				{
+				{	/* if not in oldname */
+				/* give it newname's specs for it */
 				sprintf(varspec, "%s %d", baseobs.do_nam[v],
 							baseobs.do_len[v]);
 				onum = dap_vd(varspec, 0);
-				if (dap_obs[0].do_str[v])
-					dap_obs[0].do_str[v][0] = '\0';
-				dap_obs[0].do_int[v] = 0;
-				dap_obs[0].do_dbl[v] = 0.0;
+				/* mark for setting to "", 0, and 0.0 */
+				clearvar[nclear++] = onum;
 				}
 			dap_obs[0].do_out[dap_obs[0].do_ovar++] = onum;
 			}
 		if (!(dap_out = dfopen(newname, "a")))
 			{
-			fprintf(dap_log, "(dataset) Can't append to new data set: %s\n",
+			fprintf(dap_err, "(dataset) can't append to new data set: %s\n",
 				newname);
 			exit(1);
 			}
 		while (step())
+			{
+			/* and set to "", 0, and 0.0 */
+			for (v = 0; v < nclear; v++)
+				{
+				if (dap_obs[0].do_str[clearvar[v]])
+					dap_obs[0].do_str[clearvar[v]][0] = '\0';
+				dap_obs[0].do_sl[clearvar[v]] = 0;
+				dap_obs[0].do_int[clearvar[v]] = 0;
+				dap_obs[0].do_dbl[clearvar[v]] = 0.0;
+				}
 			output();
+			}
 		for (v = 0; v < baseobs.do_nvar; v++)
+			{
 			dap_free(baseobs.do_nam[v]);
+			baseobs.do_nam[v] = NULL;
+			}
 		dap_free(varspec);
 		}
 	}
 else
 	{
-	fprintf(dap_log, "(dataset) Unknown action: %s\n", action);
+	fprintf(dap_err, "(dataset) unknown action: %s\n", action);
 	exit(1);
 	}
 dap_free(dold);
@@ -1405,6 +1447,8 @@ dap_free(oldvar);
 dap_free(newvmem);
 dap_free(newvar);
 dap_free(outlist);
+if (clearvar)
+	dap_free(clearvar);
 }
 
 #define BLOCKLEN 32
@@ -1458,7 +1502,7 @@ else
 	fname = ifname;
 	if (!idelim || !idelim[0])
 		{
-		fprintf(dap_log,
+		fprintf(dap_err,
 			"(infile) Delimiter string must be at least one character: %s\n",
 					delim);
 		exit(1);
@@ -1467,14 +1511,14 @@ else
 		strcpy(delim, idelim);
 	else
 		{
-		fprintf(dap_log,
+		fprintf(dap_err,
 			"(infile) Delimiter string too long: %s\n", idelim);
 		exit(1);
 		}
 	}
 if (!(dap_in[dap_ono] = dfopen(fname, "rf")))
 	{
-	fprintf(dap_log, "(infile) Can't read data file: %s\n", fname);
+	fprintf(dap_err, "(infile) can't read data file: %s\n", fname);
 	exit(1);
 	}
 intype = TEXT;
@@ -1497,7 +1541,7 @@ for (nfields = 0, d = 1; delim[d]; nfields++)
 		}
 	else
 		{
-		fputs("(infile) Too many field width specifiers.\n", dap_log);
+		fputs("(infile) too many field width specifiers.\n", dap_err);
 		exit(1);
 		}
 	}
@@ -1525,7 +1569,7 @@ for (v = 0; v < dap_maxvar; v++)
 dap_vd("_type_ 8", 0);
 if ((v = dap_varnum("_type_")) < 0)
 	{
-	fprintf(dap_log, "(infile(%s)) Missing _type_ variable\n", fname);
+	fprintf(dap_err, "(infile(%s)) missing _type_ variable\n", fname);
 	exit(1);
 	}
 dap_obs[dap_ono].do_out[dap_obs[dap_ono].do_ovar++] = v;
@@ -1556,7 +1600,7 @@ while (varlist[l])
 		else
 			{
 			vname[i] = '\0';
-			fprintf(dap_log, "(input) Variable name too long: %s\n", vname);
+			fprintf(dap_err, "(input) variable name too long: %s\n", vname);
 			exit(1);
 			}
 		}
@@ -1570,7 +1614,7 @@ while (varlist[l])
 		}
 	else
 		{
-		fprintf(dap_log, "(input) Unknown variable: %s\n", vname);
+		fprintf(dap_err, "(input) unknown variable: %s\n", vname);
 		exit(1);
 		}
 	l += i;
@@ -1599,19 +1643,19 @@ if (dap_out)
 	}
 if (!fname)
 	{
-	fputs("(inset) Missing input dataset name.\n", dap_log);
+	fputs("(inset) missing input dataset name.\n", dap_err);
 	exit(1);
 	}
 if (!(dap_in[dap_ono] = dfopen(fname, "r")))
 	{
-	fprintf(dap_log, "(inset) Can't read data set: %s\n", fname);
+	fprintf(dap_err, "(inset) can't read data set: %s\n", fname);
 	exit(1);
 	}
 intype = DSET;
 dap_delim = '\0';
 if (getline(dap_in[dap_ono], varspec) < 0)
 	{
-	fprintf(dap_log, "(inset) Data set empty: %s\n", fname);
+	fprintf(dap_err, "(inset) data set empty: %s\n", fname);
 	exit(1);
 	}
 nfields = 0;
@@ -1640,7 +1684,7 @@ dap_delim = SETDELIM;
 dap_vd(varspec, 1);
 if ((v = dap_varnum("_type_")) < 0)
 	{
-	fprintf(dap_log, "(inset(%s)) Missing _type_ variable\n", fname);
+	fprintf(dap_err, "(inset(%s)) missing _type_ variable\n", fname);
 	exit(1);
 	}
 dap_obs[dap_ono].do_out[dap_obs[dap_ono].do_ovar++] = v;
@@ -1673,12 +1717,12 @@ if (!fixinit)
 	}
 if (!varl)
 	{
-	fputs("(fixlist) Missing variable list.\n", dap_log);
+	fputs("(fixlist) missing variable list.\n", dap_err);
 	exit(1);
 	}
 if (!varlist)
 	{
-	fputs("(fixlist) Missing string for fixed variable list.\n", dap_log);
+	fputs("(fixlist) missing string for fixed variable list.\n", dap_err);
 	exit(1);
 	}
 /* First copy varl to varlist, eliminating bracketed indices */
@@ -1706,14 +1750,14 @@ for (nv = 0, l1 = 0; varlist[l]; )
 		else
 			{
 			vname[f] = '\0';
-			fprintf(dap_log, "(fixlist) Variable name too long: %s\n", vname);
+			fprintf(dap_err, "(fixlist) variable name too long: %s\n", vname);
 			exit(1);
 			}
 		}
 	vname[f] = '\0';
 	if (((v = dap_varnum(vname)) < 0) && ((v = dap_arrnum(vname, &dim)) < 0))
 		{
-		fprintf(dap_log, "(fixlist) Unknown variable: %s\n", vname);
+		fprintf(dap_err, "(fixlist) unknown variable: %s\n", vname);
 		exit(1);
 		}
 	for (vn = 0; vn < nv; vn++)	/* see if variable already appeared */
@@ -1757,7 +1801,7 @@ if (dap_out)
 	}
 if (!fname)
 	{
-	fputs("(outset) No dataset name.\n", dap_log);
+	fputs("(outset) no dataset name.\n", dap_err);
 	exit(1);
 	}
 if (!outinit)
@@ -1768,12 +1812,12 @@ if (!outinit)
 	}
 if (!(dap_out = dfopen(fname, "w")))
 	{
-	fprintf(dap_log, "(outset) Can't write data set: %s\n", fname);
+	fprintf(dap_err, "(outset) can't write data set: %s\n", fname);
 	exit(1);
 	}
 if (!varl)
 	{
-	fputs("(outset) Missing variable list.\n", dap_log);
+	fputs("(outset) missing variable list.\n", dap_err);
 	exit(1);
 	}
 fixlist(varl, varlist);
@@ -1795,7 +1839,7 @@ if (varlist[0])
 			}
 		else
 			{
-			fprintf(dap_log, "(outset(%s)) Unknown variable: %s\n",
+			fprintf(dap_err, "(outset(%s)) unknown variable: %s\n",
 				fname, vname);
 			exit(1);
 			}
@@ -1820,6 +1864,7 @@ for (v = 0, first = 1; v < dap_obs[dap_ono].do_ovar; v++)
 	}
 dap_putc('\n', dap_out);
 dflush(dap_out);
+outline = 0;
 }
 
 void output()
@@ -1829,7 +1874,7 @@ int first;
 
 if ((v = dap_varnum("_type_")) < 0)
 	{
-	fprintf(dap_log, "(output) Missing _type_\n");
+	fprintf(dap_err, "(output) missing _type_\n");
 	exit(1);
 	}
 for (v = 0, first = 1; v < dap_obs[dap_ono].do_ovar; v++)
@@ -1860,6 +1905,12 @@ for (v = 0, first = 1; v < dap_obs[dap_ono].do_ovar; v++)
 	}
 dap_putc('\n', dap_out);
 dflush(dap_out);
+if (dap_outreport && !(++outline % dap_outreport))
+	{
+	fprintf(stderr, "(output) %d lines written to %s...\n",
+		outline, dap_out->dfile_name);
+	fflush(stderr);
+	}
 }
 
 static int expand(char *varlist, int *varv, int maxvars)
@@ -1877,7 +1928,7 @@ if (!varlist)
         return 0;
 if (!varv)
         {
-        fputs("(expand) Missing variable index list.\n", dap_log);
+        fputs("(expand) missing variable index list.\n", dap_err);
         exit(1);
         }
 mname = dap_malloc(strlen(varlist) + 1, varlist);
@@ -1907,7 +1958,7 @@ for (nvars = 0; varlist[m]; )
 		}
         if (nvars >= maxvars)
                 {
-                fprintf(dap_log, "(expand) More than %d variables: %s\n", maxvars, varlist);
+                fprintf(dap_err, "(expand) more than %d variables: %s\n", maxvars, varlist);
                 exit(1);
                 }
 	if ((arrn = dap_arrnum(mname, &dim)) >= 0)
@@ -1938,7 +1989,7 @@ for (nvars = 0; varlist[m]; )
 		}
 	else
                 {
-                fprintf(dap_log, "(expand) variable unknown: %s\n", mname);
+                fprintf(dap_err, "(expand) variable unknown: %s\n", mname);
                 exit(1);
                 }
         }
@@ -1995,18 +2046,18 @@ int vars1null, vars2null;
 
 if (!fname1 || !fname2 || !outname)
 	{
-	fputs("(merge) Missing dataset name.\n", dap_log);
+	fputs("(merge) missing dataset name.\n", dap_err);
 	exit(1);
 	}
 if (index(vars1, '['))
 	{
-	fprintf(dap_log, "(merge) Variable lists may not contain individual array elements: %s\n",
+	fprintf(dap_err, "(merge) variable lists may not contain individual array elements: %s\n",
 			vars1);
 	exit(1);
 	}
 if (index(vars2, '['))
 	{
-	fprintf(dap_log, "(merge) Variable lists may not contain individual array elements: %s\n",
+	fprintf(dap_err, "(merge) variable lists may not contain individual array elements: %s\n",
 			vars2);
 	exit(1);
 	}
@@ -2060,7 +2111,7 @@ for (v1 = 0; v1 < nmark; v1++)	/* check types of part vars across datasets */
 	{
 	if (dap_obs[0].do_len[markv1[v1]] != dap_obs[1].do_len[markv2[v1]])
 		{
-		fprintf(dap_log,
+		fprintf(dap_err,
 		"(merge) Part variables of different types: %s (%d) and %s (%d)\n",
 			dap_obs[0].do_nam[markv1[v1]], dap_obs[0].do_len[markv1[v1]],
 			dap_obs[1].do_nam[markv2[v1]], dap_obs[1].do_len[markv2[v1]]);
@@ -2105,7 +2156,7 @@ for (v1 = 0; v1 < nvar1; v1++)
 		}
 	if (v2 < nvar2)
 		{
-		fprintf(dap_log, "(merge) Variable appears in both lists: %s\n",
+		fprintf(dap_err, "(merge) variable appears in both lists: %s\n",
 				dap_obs[0].do_nam[varv1[v1]]);
 		exit(1);
 		}
@@ -2260,7 +2311,7 @@ void dap_head(int markv[], int nmark)
 time_t t;
 int m;
 
-fputs("\n---------------------------------", dap_lst);
+fputs("\n=================================", dap_lst);
 fprintf(dap_lst, "\nDap %3d. ", pageno++);
 time(&t);
 fputs(ctime(&t), dap_lst);
