@@ -27,7 +27,7 @@ extern DFILE *dap_out;		/* output dataset file */
 extern dataobs dap_obs[];	/* values from current input line */
 extern dataobs dap_prev[];	/* values from previous input line */
 extern FILE *dap_lst;		/* .lst file */
-extern FILE *dap_log;		/* .log file */
+extern FILE *dap_err;		/* .log file */
 extern char *dap_title;		/* title for sections in .lst file */
 
 extern int dap_maxlines;	/* maximum number of lines in a ramfile */
@@ -133,7 +133,7 @@ if (!sortinit)
 	}
 if (!fname)
 	{
-	fprintf(dap_log, "%s:sort: no dataset name given\n", dap_dapname);
+	fprintf(dap_err, "%s:sort: no dataset name given\n", dap_dapname);
 	exit(1);
 	}
 scmp = &sortcmp;
@@ -169,7 +169,7 @@ if (fname[0] == '<')
 	nvar = dap_list(varlist, varv, dap_maxvar);
 	if (nmods && (nvar != nmods))
 		{
-		fprintf(dap_log,
+		fprintf(dap_err,
 		"(sort) Number of modifiers %d does not equal number of sort variables %d.\n",
 				nmods, nvar);
 		exit(1);
@@ -184,7 +184,7 @@ if (fname[0] == '<')
 				line[nlines++] = dap_in[0]->dfile_ram->rfile_str + i;
 			else
 				{
-				fprintf(dap_log, "(sort) Too many lines in ramfile %s\n",
+				fprintf(dap_err, "(sort) Too many lines in ramfile %s\n",
 							fname);
 				exit(1);
 				}
@@ -242,7 +242,7 @@ else
 					}
 				else
 					{
-					fputs("(sort) More variables than modifiers.\n", dap_log);
+					fputs("(sort) More variables than modifiers.\n", dap_err);
 					exit(1);
 					}
 				}
@@ -251,7 +251,7 @@ else
 			}
 		else
 			{
-			fprintf(dap_log, "(sort) Unknown variable: %s\n",
+			fprintf(dap_err, "(sort) Unknown variable: %s\n",
 				vname);
 			exit(1);
 			}
@@ -261,7 +261,7 @@ else
 		}
 	if (vn < nmods)
 		{
-		fputs("(sort) Fewer variables than modifiers.\n", dap_log);
+		fputs("(sort) Fewer variables than modifiers.\n", dap_err);
 		exit(1);
 		}
 	strcat(command, " >> ");
@@ -345,7 +345,7 @@ if (varlist && varlist[0])
 	{
 	if ((varv[0] = dap_varnum("_type_")) < 0)
 		{
-		fputs("(print) Missing _type_ variable.\n", dap_log);
+		fputs("(print) Missing _type_ variable.\n", dap_err);
 		exit(1);
 		}
 	nvar = 1 + dap_list(varlist, varv + 1, dap_maxvar - 1);
@@ -406,7 +406,7 @@ dap_free(formmem);
 dap_free(formstr);
 }
 
-static int meansparse(char *varlist, char *outlist, int *varv, int *wtvar, int stats[])
+int dap_mnsparse(char *varlist, char *outlist, int *varv, int *wtvar, int stats[])
 {
 int v;
 int i;
@@ -421,7 +421,7 @@ int s;
 
 if (!varlist)
 	{
-	fputs("(meansparse) Missing variable list.\n", dap_log);
+	fputs("(meansparse) Missing variable list.\n", dap_err);
 	exit(1);
 	}
 vname = dap_malloc(dap_namelen + 6, "");
@@ -444,7 +444,7 @@ while (v >= 0)
 		else
 			{
 			vname[j] = '\0';
-			fprintf(dap_log, "(meansparse) Variable name too long: %s\n",
+			fprintf(dap_err, "(meansparse) Variable name too long: %s\n",
 				vname);
 			}
 		}
@@ -461,7 +461,7 @@ while (v >= 0)
 			}
 		else
 			{
-			fprintf(dap_log, "(meansparse) Variable must be double: %s\n",
+			fprintf(dap_err, "(meansparse) Variable must be double: %s\n",
 					vname);
 			exit(1);
 			}
@@ -472,7 +472,7 @@ while (v >= 0)
 			{
 			if (s != N && stats[s])
 				{
-				fprintf(dap_log,
+				fprintf(dap_err,
 		"(meansparse) Statistics other than N requested for unknown variable %s\n",
 					vname);
 				exit(1);
@@ -517,12 +517,47 @@ dap_free(tmplist);
 return nvar;
 }
 
+/* Keep consistent with list in dap_make.h!  */
 char dap_sttnm[NSTATS][STATLEN + 1] =
-	{ "N", "SUM", "SUMWT", "MEAN", "MIN", "MAX", "RANGE", "STEPXXXX",
-	"VAR", "SD", "SEM", "VARFREQ", "SDFREQ", "SEMFREQ", "T", "TPROB",
-	"QRANGE", "SIGN", "SPROB", "SRANK", "SRPROB", "NORMAL", "NPROB",
-	"P1", "P5", "P10", "Q1", "MED", "Q3", "P90", "P95", "P99",
-	"PXXXXX", "PXXXXX", "PXXXXX" };
+{
+"N",
+"SUM",
+"SUMWT",
+"MEAN",
+"MIN",
+"MAX",
+"RANGE",
+"STEPXXXX",
+"VAR",
+"VARM",
+"SD",
+"SEM",
+"VARFREQ",
+"VARMFREQ",
+"SDFREQ",
+"SEMFREQ",
+"T",
+"TPROB",
+"QRANGE",
+"SIGN",
+"SPROB",
+"SRANK",
+"SRPROB",
+"NORMAL",
+"NPROB",
+"P1",
+"P5",
+"P10",
+"Q1",
+"MED",
+"Q3",
+"P90",
+"P95",
+"P99",
+"PXXXXX",
+"PXXXXX",
+"PXXXXX"
+};
 
 void dap_stats(char *statlist, int *stats)
 {
@@ -539,7 +574,7 @@ if (!statlist)
 	return;
 if (!stats)
 	{
-	fputs("(dap_stats) Missing statistics index list.\n", dap_log);
+	fputs("(dap_stats) Missing statistics index list.\n", dap_err);
 	exit(1);
 	}
 for (s = 0; statlist[s] == ' '; s++)
@@ -554,7 +589,7 @@ for (pctptn = 0; statlist[s]; )
 		else
 			{
 			stat[i] = '\0';
-			fprintf(dap_log, "(dap_stats) Statistic name too long: %s\n", stat);
+			fprintf(dap_err, "(dap_stats) Statistic name too long: %s\n", stat);
 			exit(1);
 			}
 		}
@@ -584,7 +619,7 @@ for (pctptn = 0; statlist[s]; )
 				}
 			else
 				{
-				fprintf(dap_log,
+				fprintf(dap_err,
 					"(dap_stats) Too many user-defined statistics: %s\n",
 					stat);
 				exit(1);
@@ -592,7 +627,7 @@ for (pctptn = 0; statlist[s]; )
 			}
 		else
 			{
-			fprintf(dap_log, "(dap_stats) Invalid statistic name: %s\n", stat);
+			fprintf(dap_err, "(dap_stats) Invalid statistic name: %s\n", stat);
 			exit(1);
 			}
 		}
@@ -618,7 +653,7 @@ dap_swap();
 dn = (double) nobs;
 if ((typevar = dap_varnum("_type_")) < 0)
 	{
-	fprintf(dap_log, "(meansout) Missing _type_ variable\n");
+	fprintf(dap_err, "(meansout) Missing _type_ variable\n");
 	exit(1);
 	}
 if (nobs >= 1)
@@ -708,6 +743,18 @@ if (nobs >= 1)
 			}
 		output();
 		}
+	if (stats[VARM])
+		{
+		strcpy(dap_obs[0].do_str[typevar], "VARM");
+		for (v = 0; v < nvar; v++)
+			{
+			if (dn > 1.0)
+				dap_obs[0].do_dbl[varv[v]] = ss[v] / (dn * (dn - 1.0));
+			else
+				dap_obs[0].do_dbl[varv[v]] = 0.0 / 0.0;
+			}
+		output();
+		}
 	if (stats[VARFREQ])
 		{
 		strcpy(dap_obs[0].do_str[typevar], "VARFREQ");
@@ -744,6 +791,18 @@ if (nobs >= 1)
 			}
 		output();
 		}
+	if (stats[VARMFREQ])
+		{
+		strcpy(dap_obs[0].do_str[typevar], "SEMFREQ");
+		for (v = 0; v < nvar; v++)
+			{
+			if (sumwt[v] > 1.0)
+				dap_obs[0].do_dbl[varv[v]] = ss[v] / (sumwt[v] * (sumwt[v] - 1.0));
+			else
+				dap_obs[0].do_dbl[varv[v]] = 0.0 / 0.0;
+			}
+		output();
+		}
 	}
 if (nobs > 1)
 	{
@@ -767,7 +826,7 @@ if (nobs > 1)
 			}
 		else
 			{
-			fprintf(dap_log, "(meansout) Bad number of steps: %s\n",
+			fprintf(dap_err, "(meansout) Bad number of steps: %s\n",
 				dap_sttnm[STEP] + 4);
 			exit(1);
 			}
@@ -812,7 +871,7 @@ if (!varlist)
 	return 0;
 if (!varv)
 	{
-	fputs("(dap_list) Missing variable index list.\n", dap_log);
+	fputs("(dap_list) Missing variable index list.\n", dap_err);
 	exit(1);
 	}
 for (m = 0; varlist[m] == ' '; m++)
@@ -827,7 +886,7 @@ for (nvars = 0; varlist[m]; )
 		else
 			{
 			mname[i] = '\0';
-			fprintf(dap_log, "(dap_list) variable name too long: %s\n",
+			fprintf(dap_err, "(dap_list) variable name too long: %s\n",
 				mname);
 			exit(1);
 			}
@@ -835,12 +894,12 @@ for (nvars = 0; varlist[m]; )
 	mname[i] = '\0';
 	if (nvars >= maxvars)
 		{
-		fprintf(dap_log, "(dap_list) More than %d variables: %s\n", maxvars, varlist);
+		fprintf(dap_err, "(dap_list) More than %d variables: %s\n", maxvars, varlist);
 		exit(1);
 		}
 	if ((varv[nvars++] = dap_varnum(mname)) < 0)
 		{
-		fprintf(dap_log, "(dap_list) variable unknown: %s\n", mname);
+		fprintf(dap_err, "(dap_list) variable unknown: %s\n", mname);
 		exit(1);
 		}
 	m += i;
@@ -913,7 +972,7 @@ int more;
 
 if (!fname)
 	{
-	fputs("(means) Missing input dataset name.\n", dap_log);
+	fputs("(means) Missing input dataset name.\n", dap_err);
 	exit(1);
 	}
 outname = dap_malloc(strlen(fname) + 5, "");
@@ -924,7 +983,7 @@ wtvar = (int *) dap_malloc(sizeof(int) * dap_maxvar, "");
 outlist = dap_malloc(dap_listlen + 1, "");
 inset(fname);
 dap_stats(statlist, stats);
-nvar = meansparse(varlist, outlist, varv, wtvar, stats);
+nvar = dap_mnsparse(varlist, outlist, varv, wtvar, stats);
 if (marks && marks[0])
 	{
 	strcat(outlist, " ");
@@ -1027,7 +1086,7 @@ static int newlab(char lname[])
 {
 if (nextclab == dap_maxclab)
 	{
-	fprintf(dap_log, "(newlab) too many column labels: %s\n", lname);
+	fprintf(dap_err, "(newlab) too many column labels: %s\n", lname);
 	exit(1);
 	}
 strcpy(collabel[nextclab].lab, lname);
@@ -1323,7 +1382,7 @@ if (collabel[upnode].labc < 0)
 	{
 	if (ncols >= dap_maxcols)
 		{
-		fputs("(findcol) too many columns in table\n", dap_log);
+		fputs("(findcol) too many columns in table\n", dap_err);
 		exit(1);
 		}
 	collabel[upnode].labc = ncols++;
@@ -1371,7 +1430,7 @@ while (rowvars[t])
 		else	
 			{
 			vname[i] = '\0';
-			fprintf(dap_log,
+			fprintf(dap_err,
 			"(specparse) Row variable name too long: %s\n",
 					vname);
 			exit(1);
@@ -1384,7 +1443,7 @@ while (rowvars[t])
 			rowvar[nrowvar++] = v;
 		else
 			{
-			fprintf(dap_log,
+			fprintf(dap_err,
 			"(specparse) Too many row variables: %s\n",
 					vname);
 			exit(1);
@@ -1392,7 +1451,7 @@ while (rowvars[t])
 		}
 	else
 		{
-		fprintf(dap_log,
+		fprintf(dap_err,
 		"(specparse) Unknown row variable: %s\n",
 				vname);
 		exit(1);
@@ -1412,7 +1471,7 @@ while (colvars[t])
                 else
                         {
 			vname[i] = '\0';
-                        fprintf(dap_log,
+                        fprintf(dap_err,
                         "(specparse) Column variable name too long: %s\n",
                                         vname);
                         exit(1);
@@ -1425,7 +1484,7 @@ while (colvars[t])
                         colvar[ncolvar++] = v;
                 else
                         {
-                        fprintf(dap_log,
+                        fprintf(dap_err,
                         "(specparse) Too many column variables: %s\n",
                                         vname);
                         exit(1);
@@ -1433,7 +1492,7 @@ while (colvars[t])
                 }
         else
                 {
-                fprintf(dap_log,
+                fprintf(dap_err,
                 "(specparse) Unknown column variable: %s\n",
                                 vname);
                 exit(1);
@@ -1459,7 +1518,7 @@ for (i = 0; format[t + i] && format[t + i] != ' '; i++)
 	else
 		{
 		vname[i] = '\0';
-		fprintf(dap_log,
+		fprintf(dap_err,
 		"(specparse) Format too long %s\n", vname);
 		exit(1);
 		}
@@ -1474,7 +1533,7 @@ if (format[t])
 		sp = 10 * sp + format[t] - '0';
 	if (format[t])
 		{
-		fprintf(dap_log,
+		fprintf(dap_err,
 			"(specparse) Extra character(s) at end of format: %s\n",
 			format);
 		exit(1);
@@ -1483,12 +1542,12 @@ if (format[t])
 	}
 if (!tabform[0])
 	{
-	fprintf(dap_log, "(specparse) No format\n");
+	fprintf(dap_err, "(specparse) No format\n");
 	exit(1);
 	}
 if (!ncolvar)
 	{
-	fputs("(specparse) No column or analysis variable(s) specified.\n", dap_log);
+	fputs("(specparse) No column or analysis variable(s) specified.\n", dap_err);
 	exit(1);
 	}
 if (ncolvar < 2)
@@ -1548,7 +1607,7 @@ if (!tabinit)
 	}
 if (!fname)
 	{
-	fputs("table: no dataset name given\n", dap_log);
+	fputs("table: no dataset name given\n", dap_err);
 	exit(1);
 	}
 inset(fname);
@@ -1556,12 +1615,12 @@ tabform[0] = '\0';
 rtitlesp = 8;
 if (!rowvars || !colvars)
 	{
-	fputs("table: no row and/or column variables specified\n", dap_log);
+	fputs("table: no row and/or column variables specified\n", dap_err);
 	exit(1);
 	}
 if (!format)
 	{
-	fputs("table: no format given\n", dap_log);
+	fputs("table: no format given\n", dap_err);
 	exit(1);
 	}
 specparse(rowvars, colvars, format);
@@ -1639,7 +1698,7 @@ for (nrows = -1, more = 1; more; )
 		}
 	if (nrows < 0)
 		{
-		fputs("(table) No rows.\n", dap_log);
+		fputs("(table) No rows.\n", dap_err);
 		exit(1);
 		}
 	for (c = 0; c < ncolvar - 1; c++)
