@@ -22,7 +22,7 @@
 
 extern dataobs dap_obs[];
 extern FILE *dap_lst;
-extern FILE *dap_log;
+extern FILE *dap_err;
 extern char *dap_dapname;
 
 extern char dap_sttnm[NSTATS][STATLEN + 1];
@@ -36,9 +36,176 @@ if (*x > *y)
 return 0;
 }
 
-static int (*cmp)() = &dblcmp;
+static int ddblcmp(double **x, double **y)
+{
+if (**x < **y)
+	return -1;
+if (**x > **y)
+	return 1;
+return 0;
+}
 
-static void pctile1(double *val[], int nobs, int *onum, int nonum, int *stats)
+static int (*cmp)() = &dblcmp;
+static int (*dcmp)() = &ddblcmp;
+
+/* Convert double percentile point to integer index, excess.  */
+static void pctpttest(double wtpt, double cumwt, double nextcum,
+				int *pctpt, int n, int *excess)
+{
+if (cumwt <= wtpt && wtpt < nextcum)
+	{
+	*pctpt = n;
+	if (wtpt > cumwt)
+		*excess = 1;
+	}
+}
+
+/* Weighted percentiles */
+static void pctile2(double ***val, int nobs,
+		int nvar, int *varv, int *wtvar, int *stats)
+{
+int v;
+int *pctptmem;
+int **pctpt;
+int *excessmem;
+int **excess;
+int pn;				/* number of user-specified percentiles */
+int pi;				/* index to user-specified percentiles */
+double pct;
+static double sumwt;		/* total sum of weights for specified variable */
+static double cumwt;		/* cumulative sum of wts for specified var */
+static double nextcum;		/* cumwt + next wt to be added in */
+static double wtpt;		/* fraction of sumwt for specified percentile */
+double upct[MAXPCTPT];		/* percent values for user-specified percentiles */
+int n;
+int ptindex;
+int s;
+double q1, q3;
+int typen;
+
+dap_swap();
+if ((typen = dap_varnum("_type_")) < 0)
+	{
+	fprintf(dap_err, "(pctile2) missing _type_ variable\n");
+	exit(1);
+	}
+pctptmem = (int *) dap_malloc(sizeof(int) * nvar * (9 + MAXPCTPT), "");
+pctpt = (int **) dap_malloc(sizeof(int *) * nvar, "");
+excessmem = (int *) dap_malloc(sizeof(int) * nvar * (9 + MAXPCTPT), "");
+excess = (int **) dap_malloc(sizeof(int *) * nvar, "");
+for (pn = 0; pn < MAXPCTPT && stats[NSTATS - MAXPCTPT + pn]; pn++)
+	{
+	if (sscanf(dap_sttnm[NSTATS - MAXPCTPT + pn] + 1,
+			"%lf", &upct[pn]) != 1)
+		{
+		fprintf(dap_err, "(pctile2) invalid percentile: %s\n",
+				dap_sttnm[NSTATS - MAXPCTPT + pn]);
+		exit(1);
+		}
+	}
+for (v = 0; v < nvar; v++)
+	{
+	pctpt[v] = pctptmem + v * (9 + MAXPCTPT);
+	excess[v] = excessmem + v * (9 + MAXPCTPT);
+	qsort((void *) val[v], (size_t) nobs, (size_t) (sizeof(double *)), dcmp);
+	for (n = 0, sumwt = 0.0; n < nobs; n++)
+		sumwt += val[v][n][1];
+	for (s = 0; s < 9 + pn; s++)
+		{
+		excess[v][s] = 0;
+		pctpt[v][s] = nobs - 1;
+		}
+	for (n = 0, cumwt = 0.0; n < nobs; n++, cumwt = nextcum)
+		{
+		nextcum = cumwt + val[v][n][1];
+		pctpttest(sumwt / 100.0, cumwt, nextcum, pctpt[v], n, excess[v]);
+		pctpttest(sumwt / 20.0, cumwt, nextcum, pctpt[v] + 1, n, excess[v] + 1);
+		pctpttest(sumwt / 10.0, cumwt, nextcum, pctpt[v] + 2, n, excess[v] + 2);
+		pctpttest(sumwt / 4.0, cumwt, nextcum, pctpt[v] + 3, n, excess[v] + 3);
+		pctpttest(sumwt / 2.0, cumwt, nextcum, pctpt[v] + 4, n, excess[v] + 4);
+		pctpttest(3.0 * sumwt / 4.0, cumwt, nextcum, pctpt[v] + 5, n, excess[v] + 5);
+		pctpttest(9.0 * sumwt / 10.0, cumwt, nextcum, pctpt[v] + 6, n, excess[v] + 6);
+		pctpttest(95.0 * sumwt / 100.0, cumwt, nextcum, pctpt[v] + 7, n, excess[v] + 7);
+		pctpttest(99.0 * sumwt / 100.0, cumwt, nextcum, pctpt[v] + 8, n, excess[v] + 8);
+		for (pi = 0; pi < pn; pi++)
+			{
+			pctpttest(upct[pi] * sumwt / 100.0,
+				cumwt, nextcum, pctpt[v] + 9 + pi,
+				n, excess[v] + 9 + pi);
+			}
+		}
+	}
+for (s = 0; s < 9 + pn; s++)
+	{
+	if (stats[P1 + s])
+		{
+		for (v = 0; v < nvar; v++)
+			{
+			ptindex = pctpt[v][s] - 1;
+			if (ptindex < 0)
+				ptindex = 0;
+			if (excess[v][s])
+				dap_obs[0].do_dbl[varv[v]] = val[v][pctpt[v][s]][0];
+			else
+				dap_obs[0].do_dbl[varv[v]] =
+					0.5 * (val[v][pctpt[v][s]][0] + val[v][ptindex][0]);
+			}
+		strcpy(dap_obs[0].do_str[typen], dap_sttnm[P1 + s]);
+		output();
+		}
+	}
+if (stats[N])
+	{
+	for (v = 0; v < nvar; v++)
+		dap_obs[0].do_dbl[varv[v]] = (double) nobs;
+	strcpy(dap_obs[0].do_str[typen], "N");
+	output();
+	}
+if (stats[MIN])
+	{
+	for (v = 0; v < nvar; v++)
+		dap_obs[0].do_dbl[varv[v]] = val[v][0][0];
+	strcpy(dap_obs[0].do_str[typen], "MIN");
+	output();
+	}
+if (stats[MAX])
+	{
+	for (v = 0; v < nvar; v++)
+		dap_obs[0].do_dbl[varv[v]] = val[v][nobs - 1][0];
+	strcpy(dap_obs[0].do_str[typen], "MAX");
+	output();
+	}
+if (stats[QRANGE])
+	{
+	for (v = 0; v < nvar; v++)
+		{
+		ptindex = pctpt[v][3] - 1;
+		if (ptindex < 0)
+			ptindex = 0;
+		if (excess[v][3])
+			q1 = val[v][pctpt[v][3]][0];
+		else
+			q1 = 0.5 * (val[v][pctpt[v][3]][0] + val[v][ptindex][0]);
+		ptindex = pctpt[v][5] - 1;
+		if (ptindex < 0)
+			ptindex = 0;
+		if (excess[v][5])
+			q3 = val[v][pctpt[v][5]][0];
+		else
+			q3 = 0.5 * (val[v][pctpt[v][5]][0] + val[v][ptindex][0]);
+		dap_obs[0].do_dbl[varv[v]] = q3 - q1;
+		}
+	strcpy(dap_obs[0].do_str[typen], "QRANGE");
+	output();
+	}
+dap_swap();
+dap_free(pctptmem);
+dap_free(pctpt);
+dap_free(excessmem);
+dap_free(excess);
+}
+
+static void pctile1(double ***val, int nobs, int nvar, int *varv, int *stats)
 {
 int v;
 double dnobs;
@@ -54,7 +221,7 @@ int typen;
 dap_swap();
 if ((typen = dap_varnum("_type_")) < 0)
 	{
-	fprintf(dap_log, "(pctile1) missing _type_ variable\n");
+	fprintf(dap_err, "(pctile1) missing _type_ variable\n");
 	exit(1);
 	}
 dnobs = (double) nobs;
@@ -76,33 +243,28 @@ pctpt[7] = (int) floor(95.0 * dnobs / 100.0);
 excess[7] = ((95.0 * dnobs / 100.0) > floor(95.0 * dnobs / 100.0));
 pctpt[8] = (int) floor(99.0 * dnobs / 100.0);
 excess[8] = ((99.0 * dnobs / 100.0) > floor(99.0 * dnobs / 100.0));
-for (pn = 0; pn < MAXPCTPT; pn++)
+for (pn = 0; pn < MAXPCTPT && stats[NSTATS - MAXPCTPT + pn]; pn++)
 	{
-	if (stats[NSTATS - MAXPCTPT + pn])
-		{
-		sscanf(dap_sttnm[NSTATS - MAXPCTPT + pn] + 1, "%lf", &pct);
-		pctpt[9 + pn] = (int) floor(pct * dnobs / 100.0);
-		excess[9 + pn] = ((pct * dnobs / 100.0) > floor(pct * dnobs / 100.0));
-		}
-	else
-		break;
+	sscanf(dap_sttnm[NSTATS - MAXPCTPT + pn] + 1, "%lf", &pct);
+	pctpt[9 + pn] = (int) floor(pct * dnobs / 100.0);
+	excess[9 + pn] = ((pct * dnobs / 100.0) > floor(pct * dnobs / 100.0));
 	}
-for (v = 0; v < nonum; v++)
-	qsort((void *) val[v], (size_t) nobs, (size_t) sizeof(double), cmp);
+for (v = 0; v < nvar; v++)
+	qsort((void *) val[v], (size_t) nobs, (size_t) sizeof(double *), dcmp);
 for (s = 0; s < 9 + pn; s++)
 	{
 	if (stats[P1 + s])
 		{
-		for (v = 0; v < nonum; v++)
+		for (v = 0; v < nvar; v++)
 			{
-			ptindex = pctpt[s] + 1;
-			if (ptindex > nobs - 1)
-				ptindex = nobs - 1;
+			ptindex = pctpt[s] - 1;
+			if (ptindex < 0)
+				ptindex = 0;
 			if (excess[s])
-				dap_obs[0].do_dbl[onum[v]] = val[v][ptindex];
+				dap_obs[0].do_dbl[varv[v]] = val[v][pctpt[s]][0];
 			else
-				dap_obs[0].do_dbl[onum[v]] =
-					0.5 * (val[v][pctpt[s]] + val[v][ptindex]);
+				dap_obs[0].do_dbl[varv[v]] =
+					0.5 * (val[v][pctpt[s]][0] + val[v][ptindex][0]);
 			}
 		strcpy(dap_obs[0].do_str[typen], dap_sttnm[P1 + s]);
 		output();
@@ -110,38 +272,44 @@ for (s = 0; s < 9 + pn; s++)
 	}
 if (stats[N])
 	{
-	for (v = 0; v < nonum; v++)
-		dap_obs[0].do_dbl[onum[v]] = dnobs;
+	for (v = 0; v < nvar; v++)
+		dap_obs[0].do_dbl[varv[v]] = dnobs;
 	strcpy(dap_obs[0].do_str[typen], "N");
 	output();
 	}
 if (stats[MIN])
 	{
-	for (v = 0; v < nonum; v++)
-		dap_obs[0].do_dbl[onum[v]] = val[v][0];
+	for (v = 0; v < nvar; v++)
+		dap_obs[0].do_dbl[varv[v]] = val[v][0][0];
 	strcpy(dap_obs[0].do_str[typen], "MIN");
 	output();
 	}
 if (stats[MAX])
 	{
-	for (v = 0; v < nonum; v++)
-		dap_obs[0].do_dbl[onum[v]] = val[v][nobs - 1];
+	for (v = 0; v < nvar; v++)
+		dap_obs[0].do_dbl[varv[v]] = val[v][nobs - 1][0];
 	strcpy(dap_obs[0].do_str[typen], "MAX");
 	output();
 	}
 if (stats[QRANGE])
 	{
-	for (v = 0; v < nonum; v++)
+	for (v = 0; v < nvar; v++)
 		{
+		ptindex = pctpt[3] - 1;
+		if (ptindex < 0)
+			ptindex = 0;
 		if (excess[3])
-			q1 = val[v][pctpt[3] + 1];
+			q1 = val[v][pctpt[3]][0];
 		else
-			q1 = 0.5 * (val[v][pctpt[3]] + val[v][pctpt[3] + 1]);
+			q1 = 0.5 * (val[v][pctpt[3]][0] + val[v][ptindex][0]);
+		ptindex = pctpt[5] - 1;
+		if (ptindex < 0)
+			ptindex = 0;
 		if (excess[5])
-			q3 = val[v][pctpt[5] + 1];
+			q3 = val[v][pctpt[5]][0];
 		else
-			q3 = 0.5 * (val[v][pctpt[5]] + val[v][pctpt[5] + 1]);
-		dap_obs[0].do_dbl[onum[v]] = q3 - q1;
+			q3 = 0.5 * (val[v][pctpt[5]][0] + val[v][ptindex][0]);
+		dap_obs[0].do_dbl[varv[v]] = q3 - q1;
 		}
 	strcpy(dap_obs[0].do_str[typen], "QRANGE");
 	output();
@@ -152,75 +320,88 @@ dap_swap();
 void pctiles(char *fname, char *varlist, char *statlist, char *marks)
 {
 char *outname;
-int *onum;
-int nvars;
-int nonum;
 int stats[NSTATS];
+int *varv;
 int *markv;
+int nvar;
 int nmark;
-char *outlist;
 int nobs;
+char *outlist;
+int *wtvar;
 int v;
 double *valmem;
-double **val;
+double **valpair;
+double ***val;
+int weighted;
 int more;
 
 if (!fname)
 	{
-	fputs("(pctiles) No dataset name given.\n", dap_log);
+	fputs("(pctiles) No dataset name given.\n", dap_err);
 	exit(1);
 	}
 outname = dap_malloc(strlen(fname) + 5, "");
-onum = (int *) dap_malloc(sizeof(int) * dap_maxvar, "");
-markv = (int *) dap_malloc(sizeof(int) * dap_maxvar, "");
 dap_suffix(outname, fname, ".pct");
+varv = (int *) dap_malloc(sizeof(int) * dap_maxvar, "");
+markv = (int *) dap_malloc(sizeof(int) * dap_maxvar, "");
+wtvar = (int *) dap_malloc(sizeof(int) * dap_maxvar, "");
+/* outlist = dap_malloc(strlen(varlist) + strlen(marks) + 2, ""); ?? */
+outlist = dap_malloc(dap_listlen + 1, "");
 inset(fname);
-nmark = dap_list(marks, markv, dap_maxvar);
-nvars = dap_list(varlist, onum, dap_maxvar);
-for (v = 0, nonum = 0; v < nvars; v++)
-	{
-	if (dap_obs[0].do_len[onum[v]] < 0)
-		onum[nonum++] = onum[v];
-	}
-outlist = dap_malloc(strlen(varlist) + strlen(marks) + 2, "");
-strcpy(outlist, varlist);
-strcat(outlist, " ");
-strcat(outlist, marks);
-outset(outname, outlist);
 dap_stats(statlist, stats);
-if (!onum)
+nvar = dap_mnsparse(varlist, outlist, varv, wtvar, stats);
+if (marks && marks[0])
+        {
+        strcat(outlist, " ");
+        strcat(outlist, marks);
+        }
+outset(outname, outlist);
+nmark = dap_list(marks, markv, dap_maxvar);
+valmem = (double *) dap_malloc(sizeof(double) * nvar * 2 * dap_maxval, "");
+valpair = (double **) dap_malloc(sizeof(double *) * nvar * dap_maxval, "");
+val = (double ***) dap_malloc(sizeof(double *) * nvar, "");
+for (v = 0, weighted = 0; v < nvar; v++)
 	{
-	fprintf(dap_log, "(pctiles) no variables specified\n");
-	exit(1);
+	if (wtvar[v] >= 0)
+		weighted = 1;
 	}
-valmem = (double *) dap_malloc(sizeof(double) * nonum * dap_maxval, "");
-val = (double **) dap_malloc(sizeof(double *) * nonum, "");
-for (v = 0; v < nonum; v++)
-	val[v] = valmem + v * dap_maxval;
 for (nobs = 0, more = 1; more; nobs++)
         {
 	more = step();
         if (dap_newpart(markv, nmark))
 		{
-		pctile1(val, nobs, onum, nonum, stats);
+		if (weighted)
+			pctile2(val, nobs, nvar, varv,  wtvar, stats);
+		else
+			pctile1(val, nobs, nvar, varv, stats);
 		nobs = 0;
 		}
 	if (nobs < dap_maxval)
 		{
-		for (v = 0; v < nonum; v++)
-			val[v][nobs] = dap_obs[0].do_dbl[onum[v]];
+		for (v = 0; v < nvar; v++)
+			{
+			valpair[dap_maxval * v + nobs] = valmem + 2 * (dap_maxval * v + nobs);
+			val[v] = valpair + v * dap_maxval;
+			val[v][nobs][0] = dap_obs[0].do_dbl[varv[v]];
+			if (wtvar[v] >= 0)
+				val[v][nobs][1] = dap_obs[0].do_dbl[wtvar[v]];
+			else
+				val[v][nobs][1] = 1.0;
+			}
 		}
 	else
 		{
-		fputs("(pctiles) Too many data.\n", dap_log);
+		fputs("(pctiles) Too many data.\n", dap_err);
 		exit(1);
 		}
 	}
 dap_free(outname);
-dap_free(onum);
+dap_free(varv);
 dap_free(markv);
+dap_free(wtvar);
 dap_free(outlist);
 dap_free(valmem);
+dap_free(valpair);
 dap_free(val);
 }
 
@@ -332,7 +513,7 @@ int more;
 
 if (!fname)
 	{
-	fputs("(corr) No dataset name given.\n", dap_log);
+	fputs("(corr) No dataset name given.\n", dap_err);
 	exit(1);
 	}
 markv = (int *) dap_malloc(sizeof(int) * dap_maxvar, "");
@@ -353,7 +534,7 @@ for (v = 0; v < nvar; v++)
 	{
 	if (dap_obs[0].do_len[varv[v]] >= 0)
 		{
-		fprintf(dap_log, "(corr) Variable not of type dap_double: %s\n",
+		fprintf(dap_err, "(corr) Variable not of type dap_double: %s\n",
 			dap_obs[0].do_nam[varv[v]]);
 		exit(1);
 		}
@@ -462,7 +643,7 @@ for (nvar = 0, number = 0; varspec[s]; nvar++)
 		else
 			{
 			varname[i] = '\0';
-			fprintf(dap_log, "(groupparse) Variable name too long: %s\n",
+			fprintf(dap_err, "(groupparse) Variable name too long: %s\n",
 					varname);
 			exit(1);
 			}
@@ -484,7 +665,7 @@ for (nvar = 0, number = 0; varspec[s]; nvar++)
 					n = 10 * n + varspec[s + i] - '0';
 				if (varspec[s + i] != ' ')
 					{
-					fprintf(dap_log, "(groupparse) Invalid ngroups: %s\n",
+					fprintf(dap_err, "(groupparse) Invalid ngroups: %s\n",
 						varspec + s);
 					exit(1);
 					}
@@ -498,7 +679,7 @@ for (nvar = 0, number = 0; varspec[s]; nvar++)
 					else
 						{
 						ctype[i] = '\0';
-						fprintf(dap_log,
+						fprintf(dap_err,
 						"(groupparse) Class type too long: %s\n",
 								ctype);
 						exit(1);
@@ -514,7 +695,7 @@ for (nvar = 0, number = 0; varspec[s]; nvar++)
 					classtype[nvar] = n;
 				else
 					{
-					fprintf(dap_log,
+					fprintf(dap_err,
 						"(groupparse) Invalid class type: %s\n",
 						ctype);
 					exit(1);
@@ -523,7 +704,7 @@ for (nvar = 0, number = 0; varspec[s]; nvar++)
 					{
 					if (n > dap_maxbars)
 						{
-						fprintf(dap_log,
+						fprintf(dap_err,
 						"(groupparse) Too many classes: %d\n", n);
 						exit(1);
 						}
@@ -531,7 +712,7 @@ for (nvar = 0, number = 0; varspec[s]; nvar++)
 				}
 			else
 				{
-				fprintf(dap_log,
+				fprintf(dap_err,
 					"(groupparse) Grouping variable must be dapdbl: %s\n",
 					varname);
 				exit(1);
@@ -557,7 +738,7 @@ for (nvar = 0, number = 0; varspec[s]; nvar++)
 		}
 	else
 		{
-		fprintf(dap_log, "(groupparse) Unknown variable: %s\n", varname);
+		fprintf(dap_err, "(groupparse) Unknown variable: %s\n", varname);
 		exit(1);
 		}
 	while (varspec[s] == ' ')
@@ -639,7 +820,7 @@ int more;
 
 if (!fname)
 	{
-	fputs("(group) No dataset name given.\n", dap_log);
+	fputs("(group) No dataset name given.\n", dap_err);
 	exit(1);
 	}
 outname = dap_malloc(strlen(fname) + 5, "");
@@ -687,7 +868,7 @@ if (nonum)
 	}
 else if (nvar >= 0)
 	{
-	fprintf(dap_log, "(group) No grouping variables: %s\n", varspec);
+	fprintf(dap_err, "(group) No grouping variables: %s\n", varspec);
 	exit(1);
 	}
 ptmem = (double *) dap_malloc(sizeof(double) * nonum * (dap_maxbars + 1), "");
@@ -755,7 +936,7 @@ for (dap_mark(), nobs = 0, more = 1; more; nobs++)
 			}
 		else
 			{
-			fputs("(group) Too many data.\n", dap_log);
+			fputs("(group) Too many data.\n", dap_err);
 			exit(1);
 			}
 		}
@@ -836,7 +1017,7 @@ while (stats[s])
 		else
 			{
 			stat[i] = '\0';
-			fprintf(dap_log, "(statparse) Statistic name too long: %s\n", stat);
+			fprintf(dap_err, "(statparse) Statistic name too long: %s\n", stat);
 			exit(1);
 			}
 		}
@@ -870,7 +1051,7 @@ while (stats[s])
 		statv[FREQNOM] = 1;
 	else
 		{
-		fprintf(dap_log, "(statparse) Invalid statistic name: %s\n", stat);
+		fprintf(dap_err, "(statparse) Invalid statistic name: %s\n", stat);
 		exit(1);
 		}
 	while (stats[s] == ' ')
@@ -910,7 +1091,7 @@ if (*nlevels < dap_maxlev)
 	}
 else
 	{
-	fprintf(dap_log, "(findlev) Too many levels at: %s\n", s);
+	fprintf(dap_err, "(findlev) Too many levels at: %s\n", s);
 	exit(1);
 	}
 }
@@ -1085,7 +1266,7 @@ if (statv[FREQODDRAT])
 		}
 	else
 		{
-		fputs("(freq2) Odds ratio computed for 2 x 2 tables only.\n", dap_log);
+		fputs("(freq2) Odds ratio computed for 2 x 2 tables only.\n", dap_err);
 		exit(1);
 		}
 	}
@@ -1158,7 +1339,7 @@ if (statv[FREQFISHER])
 		}
 	else
 		{
-		fputs("(freq2) Fisher's exact test computed for 2 x 2 tables only.\n", dap_log);
+		fputs("(freq2) Fisher's exact test computed for 2 x 2 tables only.\n", dap_err);
 		exit(1);
 		}
 	}
@@ -1234,7 +1415,7 @@ if (statv[FREQPAIR])
 	{
 	if (nlevels[0] != nlevels[1])
 		{
-		fprintf(dap_log, "(freq2) PAIR requires square table, table is %d x %d.\n",
+		fprintf(dap_err, "(freq2) PAIR requires square table, table is %d x %d.\n",
 					nlevels[0], nlevels[1]);
 		exit(1);
 		}
@@ -1340,7 +1521,7 @@ for (nvars = 0, wtvar = 0; varlist[m]; )
 		{
 		if (wtvar)
 			{
-			fprintf(dap_log,
+			fprintf(dap_err,
 				"(freqparse) Only one weight variable allowed: %s\n",
 				varlist);
 			exit(1);
@@ -1356,7 +1537,7 @@ for (nvars = 0, wtvar = 0; varlist[m]; )
                 else
                         {
                         mname[i] = '\0';
-                        fprintf(dap_log, "(dap_list) Variable name too long: %s\n",
+                        fprintf(dap_err, "(dap_list) Variable name too long: %s\n",
                                 mname);
                         exit(1);
                         }
@@ -1366,13 +1547,13 @@ for (nvars = 0, wtvar = 0; varlist[m]; )
 		{
 		if ((wt[0] = dap_varnum(mname)) < 0)
 			{
-			fprintf(dap_log, "(dap_list) Weight variable unknown: %s\n", mname);
+			fprintf(dap_err, "(dap_list) Weight variable unknown: %s\n", mname);
 			exit(1);
 			}
 		}
         else if ((varv[nvars++] = dap_varnum(mname)) < 0)
                 {
-                fprintf(dap_log, "(dap_list) Variable unknown: %s\n", mname);
+                fprintf(dap_err, "(dap_list) Variable unknown: %s\n", mname);
                 exit(1);
                 }
         m += i;
@@ -1448,7 +1629,7 @@ int (*strc)();
 strc = &strcmp;
 if (!fname)
 	{
-	fputs("(freq) No dataset name given.\n", dap_log);
+	fputs("(freq) No dataset name given.\n", dap_err);
 	exit(1);
 	}
 outname = dap_malloc(strlen(fname) + 5, "");
@@ -1472,7 +1653,7 @@ statparse(stats, statv);
 inset(fname);
 if ((typen = dap_varnum("_type_")) < 0)
 	{
-	fputs("(freq) Missing _type_ variable.\n", dap_log);
+	fputs("(freq) Missing _type_ variable.\n", dap_err);
 	exit(1);
 	}
 nmark = dap_list(marks, markv, dap_maxvar);
@@ -1481,7 +1662,7 @@ if (statv[FREQCMH] && nvar < 3)
 	{
 	fputs(
 "(freq) Cochran-Mantel-Haenszel test performed only for tables with dimension >= 3.\n",
-		dap_log);
+		dap_err);
 	exit(1);
 	}
 celln = dap_vd("_cell_ -1", 0);
@@ -1608,7 +1789,7 @@ for (nvar = 0; trimspec[n]; )
 		else
 			{
 			varname[i] = '\0';
-			fprintf(dap_log, "(trimparse) Trim variable name too long: %s\n",
+			fprintf(dap_err, "(trimparse) Trim variable name too long: %s\n",
 				varname);
 			exit(1);
 			}
@@ -1628,7 +1809,7 @@ for (nvar = 0; trimspec[n]; )
 				{
 				if (div >= 1.0)
 					{
-					fprintf(dap_log,
+					fprintf(dap_err,
 					"(trimparse) Multiple decimal points in percent for %s\n",
 						varname);
 					exit(1);
@@ -1653,7 +1834,7 @@ for (nvar = 0; trimspec[n]; )
 				nvar++;
 			else
 				{
-				fprintf(dap_log,
+				fprintf(dap_err,
 					"(trimparse) Trim variable not double: %s\n",
 						varname);
 				exit(1);
@@ -1662,7 +1843,7 @@ for (nvar = 0; trimspec[n]; )
 		}
 	else
 		{
-		fprintf(dap_log, "(trimparse) Unknown trim variable: %s\n", varname);
+		fprintf(dap_err, "(trimparse) Unknown trim variable: %s\n", varname);
 		exit(1);
 		}
 	while (trimspec[n] == ' ')
@@ -1691,7 +1872,7 @@ int more;
 
 if (!fname)
 	{
-	fputs("(trim) No dataset name given.\n", dap_log);
+	fputs("(trim) No dataset name given.\n", dap_err);
 	exit(1);
 	}
 outname = dap_malloc(strlen(fname) + 5, "");
@@ -1744,7 +1925,7 @@ for (dap_mark(), nobs = 0, more = 1; more; nobs++)
 		}
 	else
 		{
-		fputs("(group) Too many data.\n", dap_log);
+		fputs("(group) Too many data.\n", dap_err);
 		exit(1);
 		}
 	}
