@@ -23,7 +23,7 @@
 
 extern dataobs dap_obs[];
 extern FILE *dap_lst;
-extern FILE *dap_log;
+extern FILE *dap_err;
 extern char *dap_title;
 extern char *dap_dapname;
 
@@ -152,7 +152,7 @@ for (xyn = 0; xyvar[n] && xyvar[n] != ' ' && xyvar[n] != '`'; n++)
 		xyname[xyn++] = xyvar[n];
 	else
 		{
-		fprintf(dap_log, "(plotparse) X-variable name too long: %s\n", xyvar);
+		fprintf(dap_err, "(plotparse) X-variable name too long: %s\n", xyvar);
 		exit(1);
 		}
 	}
@@ -171,7 +171,7 @@ if (xyvar[n] == '`')
 			xname[xn++] = xyvar[n];
 		else
 			{
-			fprintf(dap_log, "(plotparse) X-axis label too long: %s\n", xyvar);
+			fprintf(dap_err, "(plotparse) X-axis label too long: %s\n", xyvar);
 			exit(1);
 			}
 		}
@@ -184,7 +184,7 @@ if (xyvar[n] == '`')
 		}
 	else
 		{
-		fprintf(dap_log, "(plotparse) Expected ` after x-axis label: %s\n", xyvar);
+		fprintf(dap_err, "(plotparse) Expected ` after x-axis label: %s\n", xyvar);
 		exit(1);
 		}
 	xname[xn] = '\0';
@@ -196,7 +196,7 @@ for ( ; xyvar[n] && xyvar[n] != ' ' && xyvar[n] != '`'; n++)
 		xyname[xyn++] = xyvar[n];
 	else
 		{
-		fprintf(dap_log, "(plotparse) Y-variable name too long: %s\n", xyvar);
+		fprintf(dap_err, "(plotparse) Y-variable name too long: %s\n", xyvar);
 		exit(1);
 		}
 	}
@@ -218,7 +218,7 @@ if (yname)
 				yname[yn++] = xyvar[n];
 			else
 				{
-				fprintf(dap_log, "(plotparse) Y-axis label too long: %s\n", xyvar);
+				fprintf(dap_err, "(plotparse) Y-axis label too long: %s\n", xyvar);
 				exit(1);
 				}
 			}
@@ -253,13 +253,13 @@ x = (double *) dap_malloc(dap_maxval * sizeof(double), "");
 y = (double *) dap_malloc(dap_maxval * sizeof(double), "");
 if (!fname)
 	{
-	fputs("(plot) No dataset name given.\n", dap_log);
+	fputs("(plot) No dataset name given.\n", dap_err);
 	exit(1);
 	}
 inset(fname);
 if (!xyvar)
 	{
-	fputs("(plot) No x and y variable list given.\n", dap_log);
+	fputs("(plot) No x and y variable list given.\n", dap_err);
 	exit(1);
 	}
 xyname = dap_malloc(2 * (dap_namelen + 1), "");
@@ -269,18 +269,18 @@ plotparse(xyvar, xyname, xname, yname);
 nmark = dap_list(marks, markv, dap_maxvar);
 if (dap_list(xyname, xyv, dap_maxvar) != 2)
 	{
-	fprintf(dap_log, "(plot) Invalid x and y variable list: %s\n", xyvar);
+	fprintf(dap_err, "(plot) Invalid x and y variable list: %s\n", xyvar);
 	exit(1);
 	}
 if (dap_obs[0].do_len[xyv[0]] != DBL)
 	{
-	fprintf(dap_log, "(plot) x-variable is not double variable: %s\n",
+	fprintf(dap_err, "(plot) x-variable is not double variable: %s\n",
 			dap_obs[0].do_nam[xyv[0]]);
 	exit(1);
 	}
 if (dap_obs[0].do_len[xyv[1]] != DBL)
 	{
-	fprintf(dap_log, "(plot) y-variable is not double variable: %s\n",
+	fprintf(dap_err, "(plot) y-variable is not double variable: %s\n",
 			dap_obs[0].do_nam[xyv[1]]);
 	exit(1);
 	}
@@ -310,7 +310,7 @@ for (nobs = 0, pn = 0, more = 1; more; nobs++)
 			}
 		else
 			{
-			fprintf(dap_log,
+			fprintf(dap_err,
 				"(plot) More plots than specified by nplots (%d)\n",
 						nplots);
 			exit(1);
@@ -324,7 +324,7 @@ for (nobs = 0, pn = 0, more = 1; more; nobs++)
 		}
 	else
 		{
-		fprintf(dap_log, "(plot) Too many points\n");
+		fprintf(dap_err, "(plot) Too many points\n");
 		exit(1);
 		}
 	}
@@ -375,7 +375,7 @@ if (t == -1.0 || t == 1.0)
 	return 0.0;
 tmp = 1.0 - t * t;
 x = t / sqrt(tmp);
-return exp(dkm1 * log(probn(x)) + dnmk * log(probn(-x)) - 0.5 * x * x) *
+return exp(dkm1 * log(probz(x)) + dnmk * log(probz(-x)) - 0.5 * x * x) *
 		t / (tmp * tmp);
 }
 
@@ -518,7 +518,7 @@ for (s = 0, small = 0; s < NSIMUL; s++)
 		}
 	if (ny < n)
 		{
-		fprintf(dap_log,
+		fprintf(dap_err,
 			"(probw) Only collected %d values from tree of %d values.\n",
 					ny, n);
 		exit(1);
@@ -561,7 +561,7 @@ dnobsp25 = ((double) nobs) + 0.25;
 for (r = 0, sum = 0.0, ss = 0.0, minx = 0.0, maxx = 0.0; r < nobs; r++)
 	{
 	dr = (double) r;
-	x[r] = -npoint((dr + 0.625) / dnobsp25);
+	x[r] = -zpoint((dr + 0.625) / dnobsp25);
 	if (x[r] < minx)
 		minx = x[r];
 	if (x[r] > maxx)
@@ -577,7 +577,7 @@ for (r = 0, sum = 0.0, ss = 0.0, minx = 0.0, maxx = 0.0; r < nobs; r++)
 sd = sqrt(ss / ((double) (nobs - 1)));
 if (sd == 0.0)
 	{
-	fprintf(dap_log, "(normal1) Zero standard deviation for %s\n", varname);
+	fprintf(dap_err, "(normal1) Zero standard deviation for %s\n", varname);
 	exit(1);
 	}
 if (6 < nobs && nobs <= 500)
@@ -632,7 +632,7 @@ x = (double *) dap_malloc(dap_maxval * sizeof(double), "");
 y = (double *) dap_malloc(dap_maxval * sizeof(double), "");
 if (!variable)
 	{
-	fputs("(normal) No variable specified.\n", dap_log);
+	fputs("(normal) No variable specified.\n", dap_err);
 	exit(1);
 	}
 for (t = 0; variable[t] == ' '; t++)
@@ -643,7 +643,7 @@ for (s = 0; variable[t] && variable[t] != ' ' && variable[t] != '`'; t++)
 		varname[s++] = variable[t];
 	else
 		{
-		fprintf(dap_log, "(normal) Variable name too long: %s\n", variable);
+		fprintf(dap_err, "(normal) Variable name too long: %s\n", variable);
 		exit(1);
 		}
 	}
@@ -659,7 +659,7 @@ if (variable[t] == '`')
 			varlabel[s++] = variable[t];
 		else
 			{
-			fprintf(dap_log, "(normal) Variable label too long: %s\n", variable);
+			fprintf(dap_err, "(normal) Variable label too long: %s\n", variable);
 			exit(1);
 			}
 		}
@@ -667,19 +667,19 @@ if (variable[t] == '`')
 varlabel[s] = '\0';
 if (!fname)
 	{
-	fputs("(normal) No dataset name given.\n", dap_log);
+	fputs("(normal) No dataset name given.\n", dap_err);
 	exit(1);
 	}
 inset(fname);
 nmark = dap_list(marks, markv, dap_maxvar);
 if ((vy = dap_varnum(varname)) < 0)
 	{
-	fprintf(dap_log, "(normal) Variable unknown: %s\n", varname);
+	fprintf(dap_err, "(normal) Variable unknown: %s\n", varname);
 	exit(1);
 	}
 if (dap_obs[0].do_len[vy] != DBL)
 	{
-	fprintf(dap_log, "(normal) Variable is not double variable: %s\n", varname);
+	fprintf(dap_err, "(normal) Variable is not double variable: %s\n", varname);
 	exit(1);
 	}
 for (nobs = 0, pn = 0, more = 1; more; nobs++)
@@ -692,7 +692,7 @@ for (nobs = 0, pn = 0, more = 1; more; nobs++)
 				p, l, a, pn++);
 		else
 			{
-			fprintf(dap_log,
+			fprintf(dap_err,
 				"(normal) More plots than specified by nplots (%d)\n",
 						nplots);
 			exit(1);
@@ -703,7 +703,7 @@ for (nobs = 0, pn = 0, more = 1; more; nobs++)
 		y[nobs] = dap_obs[0].do_dbl[vy];
 	else
 		{
-		fprintf(dap_log, "(normal) Too many points\n");
+		fprintf(dap_err, "(normal) Too many points\n");
 		exit(1);
 		}
 	}
@@ -763,7 +763,7 @@ h = (double *) dap_malloc(sizeof(double) * dap_maxbars, "");
 part = (double *) dap_malloc(sizeof(double) * (dap_maxbars + 1), "");
 if (!nbars)
 	{
-	fputs("(histo1) Number of bars is zero.\n", dap_log);
+	fputs("(histo1) Number of bars is zero.\n", dap_err);
 	exit(1);
 	}
 equal = 1;
@@ -785,7 +785,7 @@ if (style)
 			else
 				{
 				word[w] = '\0';
-				fprintf(dap_log, "(histo1) Style word too long: %s\n", word);
+				fprintf(dap_err, "(histo1) Style word too long: %s\n", word);
 				exit(1);
 				}
 			}
@@ -811,7 +811,7 @@ if (style)
 			}
 		else
 			{
-			fprintf(dap_log, "(histo1) Unknown style parameter: %s\n", word);
+			fprintf(dap_err, "(histo1) Unknown style parameter: %s\n", word);
 			exit(1);
 			}
 		while (style[s] == ' ')
@@ -840,7 +840,7 @@ else
 		{
 	case COUNT:
 		fputs("(histo1) Can't use count with variable width bars.\n",
-					dap_log);
+					dap_err);
 		exit(1);
 	case PERCENT:
 		strcpy(htitle, "Density (Percent)");
@@ -999,14 +999,14 @@ p = (pict *) dap_malloc(2 * nplots * sizeof(pict), "");
 a = p + nplots;
 if (!fname)
 	{
-	fputs("(histogram) No dataset name given.\n", dap_log);
+	fputs("(histogram) No dataset name given.\n", dap_err);
 	exit(1);
 	}
 inset(fname);
 nmark = dap_list(marks, markv, dap_maxvar);
 if (!vars)
 	{
-	fputs("(histogram) No variable given.\n", dap_log);
+	fputs("(histogram) No variable given.\n", dap_err);
 	exit(1);
 	}
 plotparse(vars, xwname, xname, NULL);
@@ -1015,7 +1015,7 @@ for (v = 0; v < nvar; v++)
 	{
 	if (dap_obs[0].do_len[varv[v]] != DBL)
 		{
-		fprintf(dap_log, "(histogram) Variable is not double variable: %s\n",
+		fprintf(dap_err, "(histogram) Variable is not double variable: %s\n",
 					dap_obs[0].do_nam[varv[v]]);
 		exit(1);
 		}
@@ -1032,7 +1032,7 @@ else if (nvar == 2)
 	}
 else
 	{
-	fprintf(dap_log,
+	fprintf(dap_err,
 	"(histogram) Variable list contains more than two variables: %s\n", vars);
 	exit(1);
 	}
@@ -1044,20 +1044,20 @@ for (nobs = 0, nnan = 0, pn = 0, more = 1; more; )
                 dap_swap();
 		if (nnan)
 			{
-			fprintf(dap_log, "(histogram) %d missing values for:", nnan);
+			fprintf(dap_err, "(histogram) %d missing values for:", nnan);
 			for (mv = 0; mv < nmark; mv++)
 				{
-				putc(' ', dap_log);
+				putc(' ', dap_err);
 				if (dap_obs[0].do_len[markv[mv]] == DBL)
-					fprintf(dap_log, "%g",
+					fprintf(dap_err, "%g",
 						dap_obs[0].do_dbl[markv[mv]]);
 				else if (dap_obs[0].do_len[markv[mv]] == INT)
-					fprintf(dap_log, "%d",
+					fprintf(dap_err, "%d",
 						dap_obs[0].do_int[markv[mv]]);
 				else
-					fputs(dap_obs[0].do_str[markv[mv]], dap_log);
+					fputs(dap_obs[0].do_str[markv[mv]], dap_err);
 				}
-			putc('\n', dap_log);
+			putc('\n', dap_err);
 			}
 		if (nobs)
 			{
@@ -1066,7 +1066,7 @@ for (nobs = 0, nnan = 0, pn = 0, more = 1; more; )
 					style, xfunct, markv, nmark, p, a, pn++);
 			else
 				{
-				fprintf(dap_log,
+				fprintf(dap_err,
 				"(histogram) More plots than specified by nplots (%d)\n",
 							nplots);
 				exit(1);
@@ -1098,7 +1098,7 @@ for (nobs = 0, nnan = 0, pn = 0, more = 1; more; )
 		}
         else
                 {
-                fprintf(dap_log, "(histogram) Too many points\n");
+                fprintf(dap_err, "(histogram) Too many points\n");
                 exit(1);
                 }
         }
@@ -1140,7 +1140,7 @@ strcat(srtname, ".srt");
 means(fname, x1list, "STEP100", marks);
 linreg(fname, ylist, "", x1list, marks, mnsname, level);
 dataset(fname, regname, "APPEND");
-srtarg = dap_malloc(strlen(marks) + strlen(x1list) + 8, "");
+srtarg = dap_malloc(strlen(marks) + strlen(x1list) + 9, "");
 strcpy(srtarg, marks);
 strcat(srtarg, " _type_ ");
 strcat(srtarg, x1list);
