@@ -22,7 +22,7 @@
 
 extern dataobs dap_obs[];
 extern FILE *dap_lst;
-extern FILE *dap_log;
+extern FILE *dap_err;
 extern char *dap_sttnm[NSTATS];
 
 #define TUKEY 0
@@ -235,7 +235,7 @@ dap_free(misscol);
 dap_free(term);
 if (elimrow == ncols)
 	return elimrow;
-fputs("error terms insufficient to impute missing cells\n", dap_log);
+fputs("error terms insufficient to impute missing cells\n", dap_err);
 exit(1);
 }
 
@@ -430,18 +430,18 @@ for (r = 0; r < nerrors + ncontrasts; r++)
 	if (fabs(rowsum) > dap_zerotol * rowmax)
 		{
 		if (r < nerrors)
-			fprintf(dap_log, "(sumcheck:%s) Error %d sums to %g:\n",
+			fprintf(dap_err, "(sumcheck:%s) Error %d sums to %g:\n",
 						caller, r, rowsum);
 		else
-			fprintf(dap_log, "(sumcheck:%s) Contrast %d sums to %g:\n",
+			fprintf(dap_err, "(sumcheck:%s) Contrast %d sums to %g:\n",
 					caller, r - nerrors, rowsum);
-		fprintf(dap_log, "%s%d (%x) ",
+		fprintf(dap_err, "%s%d (%x) ",
 				((r < nerrors) ? "E" : "C"),
 				((r < nerrors) ? r : r - nerrors),
 				(rterm ? rterm[r] : 0));
 		for (c = 0; c < ncells; c++)
-			fprintf(dap_log, " %g", coeff[r][c]);
-		putc('\n', dap_log);
+			fprintf(dap_err, " %g", coeff[r][c]);
+		putc('\n', dap_err);
 		exit(1);
 		}
 	}
@@ -491,14 +491,14 @@ for (firstv = 1; test[t]; )
 		else
 			{
 			vname[n] = '\0';
-			fprintf(dap_log, "(testparse) name too long: %s\n", vname);
+			fprintf(dap_err, "(testparse) name too long: %s\n", vname);
 			exit(1);
 			}
 		}
 	vname[n] = '\0';
 	if ((v = dap_varnum(vname)) < 0)
 		{
-		fprintf(dap_log, "(testparse) unknown variable: %s\n", vname);
+		fprintf(dap_err, "(testparse) unknown variable: %s\n", vname);
 		exit(1);
 		}
 	for (bit = 0x1, vv = 1; vv < nvars; vv++, bit = (bit << 1))
@@ -508,7 +508,7 @@ for (firstv = 1; test[t]; )
 		}
 	if (vv == nvars)
 		{
-		fprintf(dap_log, "(testparse) variable in test not in model: %s\n", vname);
+		fprintf(dap_err, "(testparse) variable in test not in model: %s\n", vname);
 		exit(1);
 		}
 	term |= bit;
@@ -548,7 +548,7 @@ if (l < dap_maxlev - 1)
 	}
 else
 	{
-	fprintf(dap_log, "(levn) too many levels: %s\n", levstr);
+	fprintf(dap_err, "(levn) too many levels: %s\n", levstr);
 	exit(1);
 	}
 }
@@ -1161,7 +1161,7 @@ nobs = (double *) dap_malloc(sizeof(double) * dap_maxcell, "dap_maxcell");
 vari = (double *) dap_malloc(sizeof(double) * dap_maxcell, "dap_maxcell");
 if (!fname)
 	{
-	fputs("(ftest) No dataset name given.\n", dap_log);
+	fputs("(ftest) No dataset name given.\n", dap_err);
 	exit(1);
 	}
 tstname = dap_malloc(strlen(fname) + 5, "");
@@ -1169,20 +1169,35 @@ dap_suffix(tstname, fname, "<tst");
 inset(fname);
 if ((typen = dap_varnum("_type_")) < 0)
         {
-        fprintf(dap_log, "(ftest) no _type_ variable\n");
+        fprintf(dap_err, "(ftest) no _type_ variable\n");
         exit(1);
         }
 if ((termn = dap_varnum("_term_")) < 0)
         {
-        fprintf(dap_log, "(ftest) no _term_ variable\n");
+        fprintf(dap_err, "(ftest) no _term_ variable\n");
         exit(1);
         }
 if (!variables || !variables[0])
 	{
-	fputs("(ftest) No variables given.\n", dap_log);
+	fputs("(ftest) No variables given.\n", dap_err);
 	exit(1);
 	}
 nvars = dap_list(variables, varv, dap_maxtreat + 1);
+if (dap_obs[0].do_len[varv[0]] != DBL)
+	{
+	fprintf(dap_err, "(ftest) response variable %s must be of type double\n",
+			dap_obs[0].do_nam[varv[0]]);
+	exit(1);
+	}
+for (v = 1; v < nvars; v++)
+	{
+	if (dap_obs[0].do_len[varv[v]] <= 0)
+		{
+		fprintf(dap_err, "(ftest) classification variable %s must be string\n",
+				dap_obs[0].do_nam[varv[v]]);
+		exit(1);
+		}
+	}
 outset(tstname, "");
 if (numerator && numerator[0])
 	{
@@ -1275,7 +1290,7 @@ for (ncells = 0, ncontrasts = 0, nerrors = 0,
 			}
 		else
 			{
-			fprintf(dap_log, "(ftest) Bad cell statistic: %s\n",
+			fprintf(dap_err, "(ftest) Bad cell statistic: %s\n",
 					dap_obs[0].do_str[typen]);
 			exit(1);
 			}
@@ -1292,17 +1307,17 @@ for (ncells = 0, ncontrasts = 0, nerrors = 0,
 		{
 		if (!gotm)
 			{
-			fputs("(ftest) Missing MEAN.\n", dap_log);
+			fputs("(ftest) Missing MEAN.\n", dap_err);
 			exit(1);
 			}
 		if (!gotn)
 			{
-			fputs("(ftest) Missing N.\n", dap_log);
+			fputs("(ftest) Missing N.\n", dap_err);
 			exit(1);
 			}
 		if (!gotv)
 			{
-			fputs("(ftest) Missing VAR.\n", dap_log);
+			fputs("(ftest) Missing VAR.\n", dap_err);
 			exit(1);
 			}
 		for (v = 1; v < nvars; v++)
@@ -1649,24 +1664,24 @@ for (celli = 0, celln = 0; celli < incells; celli++, celln++)
 			}
 		else
 			{
-			fprintf(dap_log, "(eff1) Bad cell statistic: %s\n",
+			fprintf(dap_err, "(eff1) Bad cell statistic: %s\n",
 					dap_obs[0].do_str[typen]);
 			exit(1);
 			}
 		}
 	if (!gotn)
 		{
-		fputs("(eff1) Missing N.\n", dap_log);
+		fputs("(eff1) Missing N.\n", dap_err);
 		exit(1);
 		}
 	if (!gotm)
 		{
-		fputs("(eff1) Missing MEAN.\n", dap_log);
+		fputs("(eff1) Missing MEAN.\n", dap_err);
 		exit(1);
 		}
 	if (!gotv)
 		{
-		fputs("(eff1) Missing VAR.\n", dap_log);
+		fputs("(eff1) Missing VAR.\n", dap_err);
 		exit(1);
 		}
 	do	{
@@ -1856,23 +1871,38 @@ for (v = 0; v < dap_maxtreat + 1; v++)
 nlevels = (int *) dap_malloc(sizeof(int) * (dap_maxtreat + 1), "dap_maxtreat");
 if (!fname)
 	{
-	fputs("(effects) No dataset name given.\n", dap_log);
+	fputs("(effects) No dataset name given.\n", dap_err);
 	exit(1);
 	}
 dap_suffix(conname, fname, ".con");
 inset(fname);
 if ((typen = dap_varnum("_type_")) < 0)
 	{
-	fputs("(effects) no _type_ variable\n", dap_log);
+	fputs("(effects) no _type_ variable\n", dap_err);
 	exit(1);
 	}
 termn = dap_vd("_term_ 0", 0);
 nvars = dap_list(varlist, varv, dap_maxtreat + 1);
 if (nvars > dap_maxtreat + 1)
 	{
-	fprintf(dap_log, "(effects) Too many variables in model: %s\n", model);
+	fprintf(dap_err, "(effects) too many variables in model: %s\n", model);
 	exit(1);
 	}
+if (dap_obs[0].do_len[varv[0]] != DBL)
+	{
+	fprintf(dap_err, "(effects) response variable %s must be of type double\n",
+			dap_obs[0].do_nam[varv[0]]);
+	exit(1);
+	}
+for (v = 1; v < nvars; v++)
+	{
+	if (dap_obs[0].do_len[varv[v]] <= 0)
+		{
+		fprintf(dap_err, "(effects) classification variable %s must be string\n",
+				dap_obs[0].do_nam[varv[v]]);
+		exit(1);
+		}
+	}
 nterm = testparse(model, termv, varv, nvars);
 nmark = dap_list(marks, markv, dap_maxvar);
 strcpy(outlist, varlist);
@@ -1917,10 +1947,10 @@ for (more = 1, incells = 0; more; incells++)
 			levn(dap_obs[0].do_str[varv[v]], levval[v], &nlevels[v]);
 		if (!step() || !step())
 			{
-			fprintf(dap_log, "(effects) Incomplete cell statistics for: ");
+			fprintf(dap_err, "(effects) Incomplete cell statistics for: ");
 			for (v = 1; v < nvars; v++)
 				{
-				fprintf(dap_log, "%s (%s) ",
+				fprintf(dap_err, "%s (%s) ",
 					dap_obs[0].do_nam[varv[v]], dap_obs[0].do_str[varv[v]]);
 				}
 			exit(1);
@@ -1986,7 +2016,7 @@ lsrow = orthog(coeff, 0, nerrors + nlevels - 1, nerrors + nlevels - 1,
 							ncells, nobs, indep, NULL);
 if (lsrow - nerrors != nlevels)
 	{
-	fprintf(dap_log,
+	fprintf(dap_err,
 		"(lsmeans1) Number of independent LS means %d differs from number of levels %d\n",
 		lsrow - nerrors, nlevels);
 	exit(1);
@@ -2247,7 +2277,7 @@ mse = 0.0;
 edf = 0.0;
 if (!fname || !fname[0])
 	{
-	fputs("(lsmeans) no dataset name given.\n", dap_log);
+	fputs("(lsmeans) no dataset name given.\n", dap_err);
 	exit(1);
 	}
 lsmname = dap_malloc(strlen(fname) + 5, fname);
@@ -2270,18 +2300,18 @@ vari = (double *) dap_malloc(sizeof(double) * dap_maxcell, "dap_maxcell");
 inset(fname);
 if (!varlist || !varlist[0])
 	{
-	fputs("(lsmeans) no variable list given.\n", dap_log);
+	fputs("(lsmeans) no variable list given.\n", dap_err);
 	exit(1);
 	}
 dap_list(varlist, varv, dap_maxtreat + 1);
 if (!treat || !treat[0])
 	{
-	fputs("(lsmeans) no treatments specified.\n", dap_log);
+	fputs("(lsmeans) no treatments specified.\n", dap_err);
 	exit(1);
 	}
 if ((treatn = dap_varnum(treat)) < 0)
 	{
-	fprintf(dap_log, "(lsmeans) Treatment variable unknown: %s\n", treat);
+	fprintf(dap_err, "(lsmeans) Treatment variable unknown: %s\n", treat);
 	exit(1);
 	}
 treat2 = dap_malloc(strlen(treat) + 2, treat);
@@ -2301,18 +2331,18 @@ sprintf(varstr, "_stat_ %d", DBL);
 statn = dap_vd(varstr, 0);
 if ((typen = dap_varnum("_type_")) < 0)
         {
-        fprintf(dap_log, "(lsmeans) no _type_ variable\n");
+        fprintf(dap_err, "(lsmeans) no _type_ variable\n");
         exit(1);
         }
 if (dap_varnum("_term_") < 0)
         {
-        fprintf(dap_log, "(lsmeans) no _term_ variable\n");
+        fprintf(dap_err, "(lsmeans) no _term_ variable\n");
         exit(1);
         }
 outset(lsmname, "");
 if (!method || !method[0])
 	{
-	fputs("(lsmeans) no method specified.\n", dap_log);
+	fputs("(lsmeans) no method specified.\n", dap_err);
 	exit(1);
 	}
 if (!strcmp(method, "TUKEY"))
@@ -2323,7 +2353,7 @@ else if (!strcmp(method, "DUNNETT"))
 	methn = DUNNETT;
 else
 	{
-	fprintf(dap_log, "(lsmeans) unknown method: %s\n", method);
+	fprintf(dap_err, "(lsmeans) unknown method: %s\n", method);
 	exit(1);
 	}
 nmark = dap_list(marks, markv, dap_maxvar);
@@ -2371,7 +2401,7 @@ for (ncells = 0, nlevels = 0, nlsmeans = 0, nerrors = 0, more = step(), morecell
                         }
                 else
                         {
-                        fprintf(dap_log, "(lsmeans) Bad cell statistic: %s\n",
+                        fprintf(dap_err, "(lsmeans) Bad cell statistic: %s\n",
                                         dap_obs[0].do_str[typen]);
                         exit(1);
                         }
@@ -2388,17 +2418,17 @@ for (ncells = 0, nlevels = 0, nlsmeans = 0, nerrors = 0, more = step(), morecell
                 {
                 if (!gotm)
                         {
-                        fputs("(lsmeans) Missing MEAN.\n", dap_log);
+                        fputs("(lsmeans) Missing MEAN.\n", dap_err);
                         exit(1);
                         }
                 if (!gotn)
                         {
-                        fputs("(lsmeans) Missing N.\n", dap_log);
+                        fputs("(lsmeans) Missing N.\n", dap_err);
                         exit(1);
                         }
                 if (!gotv)
                         {
-                        fputs("(lsmeans) Missing VAR.\n", dap_log);
+                        fputs("(lsmeans) Missing VAR.\n", dap_err);
                         exit(1);
                         }
 		levn(dap_obs[0].do_str[treatn], levval, &nlevels);
@@ -2440,7 +2470,7 @@ for (ncells = 0, nlevels = 0, nlsmeans = 0, nerrors = 0, more = step(), morecell
 			}
 		else
 			{
-			fprintf(dap_log, "(lsmeans1) Expected ERRORDF: %s\n",
+			fprintf(dap_err, "(lsmeans1) Expected ERRORDF: %s\n",
 					dap_obs[0].do_str[typen]);
 			exit(1);
 			}
