@@ -22,7 +22,7 @@
 
 extern dataobs dap_obs[];
 extern FILE *dap_lst;
-extern FILE *dap_log;
+extern FILE *dap_err;
 extern int dap_ono;
 extern char *dap_dapname;
 
@@ -71,7 +71,7 @@ double *sepred;
 dap_swap();
 if ((typen = dap_varnum("_type_")) < 0)
 	{
-	fprintf(dap_log, "(linreg1) Missing _type_ variable.\n");
+	fprintf(dap_err, "(linreg1) Missing _type_ variable.\n");
 	exit(1);
 	}
 invmem = (double *) dap_malloc(sizeof(double) * nx * nx, "");
@@ -137,7 +137,7 @@ for (c = 1; c < nx; c++)
 		}
 	else
 		{
-		fprintf(dap_log, "(linreg1) X'X matrix is singular.\n");
+		fprintf(dap_err, "(linreg1) X'X matrix is singular.\n");
 		exit(1);
 		}
 	}
@@ -188,7 +188,7 @@ putc('\n', dap_lst);
 fprintf(dap_lst, "Number of observations = %d\n", nobs);
 for (c = 0; c < ny; c++)
 	{
-	fprintf(dap_lst, "Response: %s\n", dap_obs[0].do_nam[varv[nx + c]]);
+	fprintf(dap_lst, "\nResponse: %s\n", dap_obs[0].do_nam[varv[nx + c]]);
 	fprintf(dap_lst,
 	"   F0(%d, %d) = %.6g, Prob[F > F0] = %.5f\n   R-sq = %.6g, Adj R-sq = %.6g\n",
 		nx - 1, nobs - nx, f[c],
@@ -309,7 +309,7 @@ int more;
 
 if (!fname)
 	{
-	fputs("(linreg) No dataset name given.\n", dap_log);
+	fputs("(linreg) No dataset name given.\n", dap_err);
 	exit(1);
 	}
 varv = (int *) dap_malloc(sizeof(int) * dap_maxvar, "dap_maxvar");
@@ -339,7 +339,7 @@ if (xname && xname[0])
 	nxx += dap_list(x1list, xvarv + nxx, dap_maxvar);
 	if (nxx != nx - 1)
 		{
-		fprintf(dap_log,
+		fprintf(dap_err,
 		"(linreg) %s and %s have different numbers (%d and %d) of x-variables.\n",
 			fname, xname, nx - 1, nxx);
 		exit(1);
@@ -350,7 +350,7 @@ if (xname && xname[0])
 			{
 			if ((xmarkv[v] = dap_varnum(dap_obs[0].do_nam[markv[v]])) < 0)
 				{
-				fprintf(dap_log,
+				fprintf(dap_err,
 				"(linreg) Mark variable %s in %s not in %s.\n",
 					dap_obs[0].do_nam[markv[v]], fname, xname);
 				exit(1);
@@ -359,7 +359,7 @@ if (xname && xname[0])
 		}
 	if (!step())
 		{
-		fprintf(dap_log, "(linreg) No data in %s.\n", xname);
+		fprintf(dap_err, "(linreg) No data in %s.\n", xname);
 		exit(1);
 		}
 	}
@@ -373,7 +373,7 @@ for (w = 0; w < nvar; w++)
 	{
 	if (dap_obs[0].do_len[varv[w]] != DBL)
 		{
-		fprintf(dap_log, "(linreg) Variable %s not double.\n",
+		fprintf(dap_err, "(linreg) Variable %s not double.\n",
 					dap_obs[0].do_nam[varv[w]]);
 		exit(1);
 		}
@@ -444,7 +444,7 @@ for (i = 0; yspec[l + i] && yspec[l + i] != ' ' && yspec[l + i] != '/'; i++)
 		vname[i] = yspec[l + i];
 	else
 		{
-		fprintf(dap_log, "(parsey) Variable name too long: %s\n", yspec + l);
+		fprintf(dap_err, "(parsey) Variable name too long: %s\n", yspec + l);
 		exit(1);
 		}
 	}
@@ -452,12 +452,12 @@ vname[i] = '\0';
 l += i;
 if ((vn = dap_varnum(vname)) < 0)
 	{
-	fprintf(dap_log, "(parsey) Unknown variable: %s\n", vname);
+	fprintf(dap_err, "(parsey) Unknown variable: %s\n", vname);
 	exit(1);
 	}
 if (dap_obs[dap_ono].do_len[vn] != DBL)
 	{
-	fprintf(dap_log, "(parsey) Events variable not double: %s\n", vname);
+	fprintf(dap_err, "(parsey) Events variable not double: %s\n", vname);
 	exit(1);
 	}
 varv[0] = vn;
@@ -473,7 +473,7 @@ if (yspec[l] == '/')
 			vname[i] = yspec[l + i];
 		else
 			{
-			fprintf(dap_log, "(parsey) Variable name too long: %s\n", yspec + l);
+			fprintf(dap_err, "(parsey) Variable name too long: %s\n", yspec + l);
 			exit(1);
 			}
 		}
@@ -484,7 +484,7 @@ if (yspec[l] == '/')
 		{
 		if (vname[i])
 			{
-			fprintf(dap_log, "(parsey) Invalid number of trials: %s\n", vname);
+			fprintf(dap_err, "(parsey) Invalid number of trials: %s\n", vname);
 			exit(1);
 			}
 		varv[1] = -ntrials;
@@ -493,12 +493,12 @@ if (yspec[l] == '/')
 		{
 		if ((vn = dap_varnum(vname)) < 0)
 			{
-			fprintf(dap_log, "(parsey) Unknown variable: %s\n", vname);
+			fprintf(dap_err, "(parsey) Unknown variable: %s\n", vname);
 			exit(1);
 			}
 		if (dap_obs[dap_ono].do_len[vn] != DBL)
 			{
-			fprintf(dap_log, "(parsey) Trials variable not double: %s\n", vname);
+			fprintf(dap_err, "(parsey) Trials variable not double: %s\n", vname);
 			exit(1);
 			}
 		varv[1] = vn;
@@ -506,7 +506,7 @@ if (yspec[l] == '/')
 	}
 else
 	{
-	fprintf(dap_log, "(parsey) Expected / in yspec at: %s\n", yspec + l);
+	fprintf(dap_err, "(parsey) Expected / in yspec at: %s\n", yspec + l);
 	exit(1);
 	}
 dap_free(vname);
@@ -649,7 +649,7 @@ do	{
 		}
 	if (!dap_invert(cov, nx))
 		{
-		fputs("(irls) X'DX matrix is singular\n", dap_log);
+		fputs("(irls) X'DX matrix is singular\n", dap_err);
 		exit(1);
 		}
 	for (i = 0; i < nx; i++)
@@ -713,7 +713,7 @@ beta = (double *) dap_malloc(sizeof(double) * nx, "");
 dap_swap();
 if ((typen = dap_varnum("_type_")) < 0)
 	{
-	fprintf(dap_log, "(logreg1) Missing _type_ variable.\n");
+	fprintf(dap_err, "(logreg1) Missing _type_ variable.\n");
 	exit(1);
 	}
 pr = (double *) dap_malloc(nobs * sizeof(double), "");
@@ -755,7 +755,7 @@ for (i = 0; i < nx; i++)
 		0.00001 * ceil(100000.0 * probchisq(fabs(tmp2), 1)));
 	}
 if (fabs(level) < 1.0)
-	npt = -npoint(0.5 * (1.0 - level));
+	npt = -zpoint(0.5 * (1.0 - level));
 else
 	npt = 0.0;
 dap_obs[0].do_dbl[varv[0]] = 1.0;
@@ -834,7 +834,7 @@ int more;
 
 if (!fname)
 	{
-	fputs("(logreg) No dataset name given.\n", dap_log);
+	fputs("(logreg) No dataset name given.\n", dap_err);
 	exit(1);
 	}
 varv = (int *) dap_malloc(sizeof(int) * dap_maxvar, "dap_maxvar");
@@ -866,7 +866,7 @@ if (xname && xname[0])
 	nxx += dap_list(x1list, xvarv + nxx, dap_maxvar);
 	if (nxx != nx - 1)
 		{
-		fprintf(dap_log,
+		fprintf(dap_err,
 		"(logreg) %s and %s have different numbers (%d and %d) of x-variables.\n",
 			fname, xname, nx - 1, nxx);
 		exit(1);
@@ -877,7 +877,7 @@ if (xname && xname[0])
 			{
 			if ((xmarkv[v] = dap_varnum(dap_obs[0].do_nam[markv[v]])) < 0)
 				{
-				fprintf(dap_log,
+				fprintf(dap_err,
 				"(logreg) Mark variable %s in %s not in %s.\n",
 					dap_obs[0].do_nam[markv[v]], fname, xname);
 				exit(1);
@@ -886,7 +886,7 @@ if (xname && xname[0])
 		}
 	if (!step())
 		{
-		fprintf(dap_log, "(logreg) No data in %s.\n",
+		fprintf(dap_err, "(logreg) No data in %s.\n",
 				(xname[0] ? xname : fname));
 		exit(1);
 		}
@@ -923,7 +923,7 @@ for (nobs = 0, dap_mark(), more = 1; more; nobs++)
 		}
 	else
 		{
-		fputs("(logreg) Too many data.\n", dap_log);
+		fputs("(logreg) Too many data.\n", dap_err);
 		exit(1);
 		}
 	}
@@ -1047,7 +1047,7 @@ if (nvar == 2)
 				kolval = tmp1;
 				}
 			}
-		fprintf(dap_lst, "Response: %s\n", dap_obs[0].do_nam[varv[0]]);
+		fprintf(dap_lst, "\nResponse: %s\n", dap_obs[0].do_nam[varv[0]]);
 		fprintf(dap_lst, "Classified by %s:", dap_obs[0].do_nam[varv[1]]);
 		for (r = 0; r < nlevels; r++)
 			fprintf(dap_lst, " %s (%d)", level[r], levnobs[r]);
@@ -1096,7 +1096,7 @@ if (nvar == 2)
 			{
 			if (stat0 >= 0.5)
 				stat0 -= 0.5;
-			prob = 2.0 * (1.0 - probn(stat0 /
+			prob = 2.0 * (1.0 - probz(stat0 /
 					sqrt(((double) (levnobs[0] * levnobs[1])) *
 					((dn + 1.0) - tiecorr /
 					(dn * (dn - 1.0))) / 12.0)));
@@ -1138,7 +1138,7 @@ if (nvar == 2)
 			stat0 += tmp * tmp * (double) levnobs[levn];
 			}
 		stat0 *= 12.0 / (dn * (dn + 1.0) - tiecorr / (dn - 1.0));
-		fprintf(dap_lst, "Response: %s\n", dap_obs[0].do_nam[varv[0]]);
+		fprintf(dap_lst, "\nResponse: %s\n", dap_obs[0].do_nam[varv[0]]);
 		fprintf(dap_lst, "Classified by %s:", dap_obs[0].do_nam[varv[1]]);
 		for (levn = 0, minnobs = levnobs[0]; levn < nlevels; levn++)
 			{
@@ -1161,7 +1161,7 @@ if (nvar == 2)
 	}
 else
 	{
-	fprintf(dap_lst, "Response: %s\n", dap_obs[0].do_nam[varv[0]]);
+	fprintf(dap_lst, "\nResponse: %s\n", dap_obs[0].do_nam[varv[0]]);
 	fprintf(dap_lst, "Number of non-zero observations = %d\n", nval);
 	qsort(val, nval, sizeof(value), pvalcmp1);
 	for (rank = 0, stat0 = 0.0, tottied = 0, tiecorr = 0, levnobs[0] = 0; rank < nval; )
@@ -1254,7 +1254,7 @@ if (*nlevels < dap_maxlev)
 	}
 else
 	{
-	fprintf(dap_log, "(findlev) Too many levels (%s)\n", levname);
+	fprintf(dap_err, "(findlev) Too many levels (%s)\n", levname);
 	exit(1);
 	}
 }
@@ -1275,7 +1275,7 @@ int more;
 
 if (!fname)
 	{
-	fputs("(nonparam) No dataset name given.\n", dap_log);
+	fputs("(nonparam) No dataset name given.\n", dap_err);
 	exit(1);
 	}
 markv = (int *) dap_malloc(sizeof(int) * dap_maxvar, "dap_maxvar");
@@ -1287,23 +1287,23 @@ inset(fname);
 nvar = dap_list(variables, varv, dap_maxvar);
 if (!nvar)
 	{
-	fputs("(nonparam) No variables specified.\n", dap_log);
+	fputs("(nonparam) No variables specified.\n", dap_err);
 	exit(1);
 	}
 if (nvar > 2)
 	{
-	fputs("(nonparam) At most one response and one class variable allowed\n", dap_log);
+	fputs("(nonparam) At most one response and one class variable allowed\n", dap_err);
 	exit(1);
 	}
 if (dap_obs[0].do_len[varv[0]] != DBL)
 	{
-	fprintf(dap_log, "(nonparam) Variable must be dap_double: %s\n",
+	fprintf(dap_err, "(nonparam) Variable must be dap_double: %s\n",
 			dap_obs[0].do_nam[varv[0]]);
 	exit(1);
 	}
 if (nvar == 2 && dap_obs[0].do_len[varv[1]] <= 0)
 	{
-	fprintf(dap_log, "(nonparam) Classification variable must be dap_char: %s\n",
+	fprintf(dap_err, "(nonparam) Classification variable must be dap_char: %s\n",
 			dap_obs[0].do_nam[varv[1]]);
 	exit(1);
 	}
@@ -1327,7 +1327,7 @@ for (more = 1, nlevels = 0, nval = 0, nobs = 0; more; nobs++)
 		}
 	if (nval >= dap_maxval)
 		{
-		fputs("(nonparam) Too many values.\n", dap_log);
+		fputs("(nonparam) Too many values.\n", dap_err);
 		exit(1);
 		}
 	if (nvar == 2)
