@@ -40,10 +40,12 @@
 #define RANGE (MAX+1)
 #define STEP (RANGE+1)
 #define VAR (STEP+1)
-#define SD (VAR+1)
+#define VARM (VAR+1)
+#define SD (VARM+1)
 #define SEM (SD+1)
 #define VARFREQ (SEM+1)
-#define SDFREQ (VARFREQ+1)
+#define VARMFREQ (VARFREQ+1)
+#define SDFREQ (VARMFREQ+1)
 #define SEMFREQ (SDFREQ+1)
 #define T (SEMFREQ+1)
 #define TPROB (T+1)
@@ -143,9 +145,9 @@ double varunif();
 double probt(double t1, int di);
 double chisqpoint(double p, int df);
 double fpoint(double p, int numdf, int dendf);
-double npoint(double p);
+double zpoint(double p);
 double tpoint(double p, int in);
-double probn(double z1);
+double probz(double z1);
 double probf(double f2, int id1, int id2);
 double probchisq(double x2, int df);
 double dap_sr(int numdf, int dendf, double pt);
@@ -173,3 +175,4 @@ void dap_putdouble(double x, DFILE *dfp);
 double dap_getdouble(char code[]);
 void dap_putint(int i, DFILE *dfp);
 int dap_getint(char code[]);
+int dap_mnsparse(char *varlist, char *outlist, int *varv, int *wtvar, int stats[]);
