@@ -4,7 +4,6 @@
  * 3. Processes infile and inset statements.  
  * 4. Adds necessary function calls for variable
  *    declarations in infile and inset statement bodies.  
- * 5. Adds a function dap_params() if it's not there. 
  */
 
 /*  Copyright (C) 2001  Susan Bassein
@@ -48,7 +47,6 @@ int inquote2;		/* flag: inside double quotes? */
 int escape;		/* flag: was previous character a backslash,
 			 * outside comments but inside quotes?
 			 */
-int gotparam;		/* flag: found dap_param()? */
 
 typedef struct		/* defines for array dimensions */
 {
@@ -403,7 +401,7 @@ while (gettoken(token, dotc, dapc, 0))
 				exit(1);
 				}
 			}
-		else
+		else if (!strcmp(tokdel, ",") || !strcmp(tokdel, ";"))
 			{
 			if (!strcmp(decl, "int"))
 				{
@@ -626,11 +624,6 @@ while (gettoken(token, dotc, dapc, 1))
 			exit(1);
 			}
 		}
-	else if (!strcmp(token, "dap_param"))
-		{
-		if (gettoken(tokdel, dotc, dapc, 1) && !strcmp(tokdel, "("))
-			gotparam = 1;
-		}
 	}
 return 0;
 }
@@ -682,11 +675,8 @@ while (--argc > 0)
 	inquote2 = 0;
 	escape = 0;
 	ndef = 0;
-	gotparam = 0;
 	while (infile(dotc, dapc))
 		preproc(dotc, dapc);
-	if (!gotparam)
-		fputs("\nvoid dap_param() {}\n", dapc);
 		
 	fclose(dotc);
 	fclose(dapc);
