@@ -22,7 +22,7 @@
 #include <math.h>
 #include "dap_make.h"
 
-extern FILE *dap_log;
+extern FILE *dap_err;
 
 static int mdays[] = { 0, 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31 };
 
@@ -148,7 +148,7 @@ if (trace)
 		tr = 2;
 	else
 		{
-		fprintf(dap_log, "(maximize) Bad tracing option: %s\n", trace);
+		fprintf(dap_err, "(maximize) Bad tracing option: %s\n", trace);
 		exit(1);
 		}
 	}
@@ -179,10 +179,10 @@ for (f0 = (*f)(x), s[0] = -step, s[1] = step; ; )
 		}
 	if (tr == 1)
 		{
-		fprintf(dap_log, "(maximize) f = %g, step = %g\n", f0, step);
+		fprintf(dap_err, "(maximize) f = %g, step = %g\n", f0, step);
 		for (n = 0; n < nx; n++)
-			fprintf(dap_log, "%g ", x[n]);
-		putc('\n', dap_log);
+			fprintf(dap_err, "%g ", x[n]);
+		putc('\n', dap_err);
 		}
 	else if (tr == 2)
 		{
@@ -198,7 +198,7 @@ for (f0 = (*f)(x), s[0] = -step, s[1] = step; ; )
 		s[1] = step;
 		if (tr)
 			{
-			fprintf(dap_log, "(maximize) Setting step to %g\n", step);
+			fprintf(dap_err, "(maximize) Setting step to %g\n", step);
 			if (tr == 2)
 				getchar();
 			}
@@ -213,10 +213,10 @@ for (f0 = (*f)(x), s[0] = -step, s[1] = step; ; )
 		x[maxdir] += dirstep;
 		if (tr)
 			{
-			fputs("(maximize)", dap_log);
+			fputs("(maximize)", dap_err);
 			for (n = 0; n < nx; n++)
-				fprintf(dap_log, " %g", x[n]);
-			putc('\n', dap_log);
+				fprintf(dap_err, " %g", x[n]);
+			putc('\n', dap_err);
 			if (tr == 2)
 				getchar();
 			}
