@@ -33,7 +33,7 @@
 #define TWOOVERSQRT3 1.15470053837925153
 #define ONEOVERSQRT3 0.57735026918962576
 
-extern FILE *dap_log;
+extern FILE *dap_err;
 
 static int orient;
 static int bboxx0, bboxy0, bboxx1, bboxy1;
@@ -72,7 +72,7 @@ if (ptnext < dap_maxpts)
 	}
 else
 	{
-	fputs("(pict_newpoint) Too many points.\n", dap_log);
+	fputs("(pict_newpoint) Too many points.\n", dap_err);
 	exit(1);
 	}
 return pt;
@@ -92,7 +92,7 @@ if (str)
 			charbuf[charnext++] = str[s];
 		else
 			{
-			fputs("(pict_newstr) Too many characters.\n", dap_log);
+			fputs("(pict_newstr) Too many characters.\n", dap_err);
 			exit(1);
 			}
 		}
@@ -109,7 +109,7 @@ if (!pict_out)
 	{
 	if (!(pict_out = fopen(dap_psname, "w")))
 		{
-		fprintf(dap_log, "(pict_init) Can't create .ps file: %s\n", dap_psname);
+		fprintf(dap_err, "(pict_init) Can't create .ps file: %s\n", dap_psname);
 		exit(1);
 		}
 	}
@@ -236,13 +236,13 @@ if (p->pict_ntxt < dap_maxntxt - 1)
 		if ((pos[0] != 'l' && pos[0] != 'c' && pos[0] != 'r') ||
 				(pos[1] != 't' && pos[1] != 'm' && pos[1] != 'b'))
 			{
-			fprintf(dap_log, "(pict_text) Invalid position string: %s\n", pos);
+			fprintf(dap_err, "(pict_text) Invalid position string: %s\n", pos);
 			exit(1);
 			}
 		}
 	else
 		{
-		fprintf(dap_log, "(pict_text) Position string too long: %s\n", pos);
+		fprintf(dap_err, "(pict_text) Position string too long: %s\n", pos);
 		exit(1);
 		}
 	p->pict_tang[p->pict_ntxt] = tang;
@@ -250,7 +250,7 @@ if (p->pict_ntxt < dap_maxntxt - 1)
 	}
 else
 	{
-	fprintf(dap_log, "(pict_text) Too many texts in pict\n");
+	fprintf(dap_err, "(pict_text) Too many texts in pict\n");
 	exit(1);
 	}
 }
@@ -560,7 +560,7 @@ else if (!strcmp(type, "DIAM")) return DIAM;
 else if (!strcmp(type, "PATT")) return PATT;
 else
 	{
-	fprintf(dap_log, "bad pict type: %s\n", type);
+	fprintf(dap_err, "bad pict type: %s\n", type);
 	exit(1);
 	}
 }
@@ -574,7 +574,7 @@ switch (picttype(p->pict_type))
 case SEGM:
 	if (p->pict_npts % 2)
 		{
-		fputs("(show0) Requested SEGM with odd number of points.\n", dap_log);
+		fputs("(show0) Requested SEGM with odd number of points.\n", dap_err);
 		exit(1);
 		}
 	for (ptn = 0; ptn < p->pict_npts; ptn += 2)
@@ -588,7 +588,7 @@ case SEGM:
 case IBEA:
 	if (p->pict_npts % 2)
 		{
-		fputs("(show0) Requested IBEA with odd number of points.\n", dap_log);
+		fputs("(show0) Requested IBEA with odd number of points.\n", dap_err);
 		exit(1);
 		}
 	for (ptn = 0; ptn < p->pict_npts; ptn += 2)
@@ -625,7 +625,7 @@ case IBEA:
 			}
 		else
 			{
-			fprintf(dap_log,
+			fprintf(dap_err,
 "(show0) IBEA requested but neither x nor y coordinates match: (%g, %g), (%g, %g)\n",
 					p->pict_pt[ptn][0], p->pict_pt[ptn][1],
 					p->pict_pt[ptn + 1][0], p->pict_pt[ptn + 1][1]);
@@ -784,7 +784,7 @@ for (t = 0; t < p->pict_ntxt; t++)
 				baret[i++] = p->pict_txt[t][tc];
 			else
 				{
-				fprintf(dap_log, "(show1) Text too long: %s\n",
+				fprintf(dap_err, "(show1) Text too long: %s\n",
 							p->pict_txt[t]);
 				exit(1);
 				}
@@ -855,7 +855,7 @@ for (t = 0; t < p->pict_ntxt; t++)
 				tpart[i] = p->pict_txt[t][tc];
 			else
 				{
-				fprintf(dap_log, "(show1) Text too long: %s\n",
+				fprintf(dap_err, "(show1) Text too long: %s\n",
 							p->pict_txt[t]);
 				exit(1);
 				}
@@ -908,7 +908,7 @@ int pn;
 
 if (nplots % nperpage)
 	{
-	fprintf(dap_log,
+	fprintf(dap_err,
 	"(nport) Number of plots %d not a multiple of number per page %d\n",
 		nplots, nperpage);
 	exit(1);
@@ -928,7 +928,7 @@ int pn;
 
 if (nplots % nperpage)
         {
-        fprintf(dap_log,
+        fprintf(dap_err,
         "(pict_nlandscape) Number of plots %d not a multiple of number per page %d\n",
                 nplots, nperpage);
         exit(1);
